downloadrecord

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the downloadrecord type in the database.
	Label = "download_record"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldTitle holds the string denoting the title field in the database.
	FieldTitle = "title"
	// FieldQuality holds the string denoting the quality field in the database.
	FieldQuality = "quality"
	// FieldSize holds the string denoting the size field in the database.
	FieldSize = "size"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldTorrentHash holds the string denoting the torrent_hash field in the database.
	FieldTorrentHash = "torrent_hash"
	// FieldReleaseGroup holds the string denoting the release_group field in the database.
	FieldReleaseGroup = "release_group"
	// FieldSavePath holds the string denoting the save_path field in the database.
	FieldSavePath = "save_path"
	// FieldImportAttempts holds the string denoting the import_attempts field in the database.
	FieldImportAttempts = "import_attempts"
	// FieldFailureReason holds the string denoting the failure_reason field in the database.
	FieldFailureReason = "failure_reason"
	// FieldImportedAt holds the string denoting the imported_at field in the database.
	FieldImportedAt = "imported_at"
	// FieldIndexerName holds the string denoting the indexer_name field in the database.
	FieldIndexerName = "indexer_name"
	// FieldDownloadClientName holds the string denoting the download_client_name field in the database.
	FieldDownloadClientName = "download_client_name"
	// FieldReplaceExisting holds the string denoting the replace_existing field in the database.
	FieldReplaceExisting = "replace_existing"
	// EdgeMovie holds the string denoting the movie edge name in mutations.
	EdgeMovie = "movie"
	// EdgeEpisode holds the string denoting the episode edge name in mutations.
	EdgeEpisode = "episode"
	// Table holds the table name of the downloadrecord in the database.
	Table = "download_records"
	// MovieTable is the table that holds the movie relation/edge.
	MovieTable = "download_records"
	// MovieInverseTable is the table name for the Movie entity.
	// It exists in this package in order to avoid circular dependency with the "movie" package.
	MovieInverseTable = "movies"
	// MovieColumn is the table column denoting the movie relation/edge.
	MovieColumn = "movie_download_records"
	// EpisodeTable is the table that holds the episode relation/edge.
	EpisodeTable = "download_records"
	// EpisodeInverseTable is the table name for the Episode entity.
	// It exists in this package in order to avoid circular dependency with the "episode" package.
	EpisodeInverseTable = "episodes"
	// EpisodeColumn is the table column denoting the episode relation/edge.
	EpisodeColumn = "episode_download_records"
)
const DefaultStatus = StatusDownloading

StatusDownloading is the default value of the Status enum.

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// TitleValidator is a validator for the "title" field. It is called by the builders before save.
	TitleValidator func(string) error
	// DefaultImportAttempts holds the default value on creation for the "import_attempts" field.
	DefaultImportAttempts uint8
	// DefaultReplaceExisting holds the default value on creation for the "replace_existing" field.
	DefaultReplaceExisting bool
)

Columns holds all SQL columns for downloadrecord fields.

var ForeignKeys = []string{
	"episode_download_records",
	"movie_download_records",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "download_records" table and are not defined as standalone fields in the schema.

Functions

func And

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.DownloadRecord

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.DownloadRecord

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.DownloadRecord

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.DownloadRecord

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.DownloadRecord

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.DownloadRecord

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.DownloadRecord

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.DownloadRecord

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.DownloadRecord

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func DownloadClientName

func DownloadClientName(v string) predicate.DownloadRecord

DownloadClientName applies equality check predicate on the "download_client_name" field. It's identical to DownloadClientNameEQ.

func DownloadClientNameContains

func DownloadClientNameContains(v string) predicate.DownloadRecord

DownloadClientNameContains applies the Contains predicate on the "download_client_name" field.

func DownloadClientNameContainsFold

func DownloadClientNameContainsFold(v string) predicate.DownloadRecord

DownloadClientNameContainsFold applies the ContainsFold predicate on the "download_client_name" field.

func DownloadClientNameEQ

func DownloadClientNameEQ(v string) predicate.DownloadRecord

DownloadClientNameEQ applies the EQ predicate on the "download_client_name" field.

func DownloadClientNameEqualFold

func DownloadClientNameEqualFold(v string) predicate.DownloadRecord

DownloadClientNameEqualFold applies the EqualFold predicate on the "download_client_name" field.

func DownloadClientNameGT

func DownloadClientNameGT(v string) predicate.DownloadRecord

DownloadClientNameGT applies the GT predicate on the "download_client_name" field.

func DownloadClientNameGTE

func DownloadClientNameGTE(v string) predicate.DownloadRecord

DownloadClientNameGTE applies the GTE predicate on the "download_client_name" field.

func DownloadClientNameHasPrefix

func DownloadClientNameHasPrefix(v string) predicate.DownloadRecord

DownloadClientNameHasPrefix applies the HasPrefix predicate on the "download_client_name" field.

func DownloadClientNameHasSuffix

func DownloadClientNameHasSuffix(v string) predicate.DownloadRecord

DownloadClientNameHasSuffix applies the HasSuffix predicate on the "download_client_name" field.

func DownloadClientNameIn

func DownloadClientNameIn(vs ...string) predicate.DownloadRecord

DownloadClientNameIn applies the In predicate on the "download_client_name" field.

func DownloadClientNameIsNil

func DownloadClientNameIsNil() predicate.DownloadRecord

DownloadClientNameIsNil applies the IsNil predicate on the "download_client_name" field.

func DownloadClientNameLT

func DownloadClientNameLT(v string) predicate.DownloadRecord

DownloadClientNameLT applies the LT predicate on the "download_client_name" field.

func DownloadClientNameLTE

func DownloadClientNameLTE(v string) predicate.DownloadRecord

DownloadClientNameLTE applies the LTE predicate on the "download_client_name" field.

func DownloadClientNameNEQ

func DownloadClientNameNEQ(v string) predicate.DownloadRecord

DownloadClientNameNEQ applies the NEQ predicate on the "download_client_name" field.

func DownloadClientNameNotIn

func DownloadClientNameNotIn(vs ...string) predicate.DownloadRecord

DownloadClientNameNotIn applies the NotIn predicate on the "download_client_name" field.

func DownloadClientNameNotNil

func DownloadClientNameNotNil() predicate.DownloadRecord

DownloadClientNameNotNil applies the NotNil predicate on the "download_client_name" field.

func FailureReason

func FailureReason(v string) predicate.DownloadRecord

FailureReason applies equality check predicate on the "failure_reason" field. It's identical to FailureReasonEQ.

func FailureReasonContains

func FailureReasonContains(v string) predicate.DownloadRecord

FailureReasonContains applies the Contains predicate on the "failure_reason" field.

func FailureReasonContainsFold

func FailureReasonContainsFold(v string) predicate.DownloadRecord

FailureReasonContainsFold applies the ContainsFold predicate on the "failure_reason" field.

func FailureReasonEQ

func FailureReasonEQ(v string) predicate.DownloadRecord

FailureReasonEQ applies the EQ predicate on the "failure_reason" field.

func FailureReasonEqualFold

func FailureReasonEqualFold(v string) predicate.DownloadRecord

FailureReasonEqualFold applies the EqualFold predicate on the "failure_reason" field.

func FailureReasonGT

func FailureReasonGT(v string) predicate.DownloadRecord

FailureReasonGT applies the GT predicate on the "failure_reason" field.

func FailureReasonGTE

func FailureReasonGTE(v string) predicate.DownloadRecord

FailureReasonGTE applies the GTE predicate on the "failure_reason" field.

func FailureReasonHasPrefix

func FailureReasonHasPrefix(v string) predicate.DownloadRecord

FailureReasonHasPrefix applies the HasPrefix predicate on the "failure_reason" field.

func FailureReasonHasSuffix

func FailureReasonHasSuffix(v string) predicate.DownloadRecord

FailureReasonHasSuffix applies the HasSuffix predicate on the "failure_reason" field.

func FailureReasonIn

func FailureReasonIn(vs ...string) predicate.DownloadRecord

FailureReasonIn applies the In predicate on the "failure_reason" field.

func FailureReasonIsNil

func FailureReasonIsNil() predicate.DownloadRecord

FailureReasonIsNil applies the IsNil predicate on the "failure_reason" field.

func FailureReasonLT

func FailureReasonLT(v string) predicate.DownloadRecord

FailureReasonLT applies the LT predicate on the "failure_reason" field.

func FailureReasonLTE

func FailureReasonLTE(v string) predicate.DownloadRecord

FailureReasonLTE applies the LTE predicate on the "failure_reason" field.

func FailureReasonNEQ

func FailureReasonNEQ(v string) predicate.DownloadRecord

FailureReasonNEQ applies the NEQ predicate on the "failure_reason" field.

func FailureReasonNotIn

func FailureReasonNotIn(vs ...string) predicate.DownloadRecord

FailureReasonNotIn applies the NotIn predicate on the "failure_reason" field.

func FailureReasonNotNil

func FailureReasonNotNil() predicate.DownloadRecord

FailureReasonNotNil applies the NotNil predicate on the "failure_reason" field.

func HasEpisode

func HasEpisode() predicate.DownloadRecord

HasEpisode applies the HasEdge predicate on the "episode" edge.

func HasEpisodeWith

func HasEpisodeWith(preds ...predicate.Episode) predicate.DownloadRecord

HasEpisodeWith applies the HasEdge predicate on the "episode" edge with a given conditions (other predicates).

func HasMovie

func HasMovie() predicate.DownloadRecord

HasMovie applies the HasEdge predicate on the "movie" edge.

func HasMovieWith

func HasMovieWith(preds ...predicate.Movie) predicate.DownloadRecord

HasMovieWith applies the HasEdge predicate on the "movie" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint32) predicate.DownloadRecord

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint32) predicate.DownloadRecord

IDNotIn applies the NotIn predicate on the ID field.

func ImportAttempts

func ImportAttempts(v uint8) predicate.DownloadRecord

ImportAttempts applies equality check predicate on the "import_attempts" field. It's identical to ImportAttemptsEQ.

func ImportAttemptsEQ

func ImportAttemptsEQ(v uint8) predicate.DownloadRecord

ImportAttemptsEQ applies the EQ predicate on the "import_attempts" field.

func ImportAttemptsGT

func ImportAttemptsGT(v uint8) predicate.DownloadRecord

ImportAttemptsGT applies the GT predicate on the "import_attempts" field.

func ImportAttemptsGTE

func ImportAttemptsGTE(v uint8) predicate.DownloadRecord

ImportAttemptsGTE applies the GTE predicate on the "import_attempts" field.

func ImportAttemptsIn

func ImportAttemptsIn(vs ...uint8) predicate.DownloadRecord

ImportAttemptsIn applies the In predicate on the "import_attempts" field.

func ImportAttemptsLT

func ImportAttemptsLT(v uint8) predicate.DownloadRecord

ImportAttemptsLT applies the LT predicate on the "import_attempts" field.

func ImportAttemptsLTE

func ImportAttemptsLTE(v uint8) predicate.DownloadRecord

ImportAttemptsLTE applies the LTE predicate on the "import_attempts" field.

func ImportAttemptsNEQ

func ImportAttemptsNEQ(v uint8) predicate.DownloadRecord

ImportAttemptsNEQ applies the NEQ predicate on the "import_attempts" field.

func ImportAttemptsNotIn

func ImportAttemptsNotIn(vs ...uint8) predicate.DownloadRecord

ImportAttemptsNotIn applies the NotIn predicate on the "import_attempts" field.

func ImportedAt

func ImportedAt(v time.Time) predicate.DownloadRecord

ImportedAt applies equality check predicate on the "imported_at" field. It's identical to ImportedAtEQ.

func ImportedAtEQ

func ImportedAtEQ(v time.Time) predicate.DownloadRecord

ImportedAtEQ applies the EQ predicate on the "imported_at" field.

func ImportedAtGT

func ImportedAtGT(v time.Time) predicate.DownloadRecord

ImportedAtGT applies the GT predicate on the "imported_at" field.

func ImportedAtGTE

func ImportedAtGTE(v time.Time) predicate.DownloadRecord

ImportedAtGTE applies the GTE predicate on the "imported_at" field.

func ImportedAtIn

func ImportedAtIn(vs ...time.Time) predicate.DownloadRecord

ImportedAtIn applies the In predicate on the "imported_at" field.

func ImportedAtIsNil

func ImportedAtIsNil() predicate.DownloadRecord

ImportedAtIsNil applies the IsNil predicate on the "imported_at" field.

func ImportedAtLT

func ImportedAtLT(v time.Time) predicate.DownloadRecord

ImportedAtLT applies the LT predicate on the "imported_at" field.

func ImportedAtLTE

func ImportedAtLTE(v time.Time) predicate.DownloadRecord

ImportedAtLTE applies the LTE predicate on the "imported_at" field.

func ImportedAtNEQ

func ImportedAtNEQ(v time.Time) predicate.DownloadRecord

ImportedAtNEQ applies the NEQ predicate on the "imported_at" field.

func ImportedAtNotIn

func ImportedAtNotIn(vs ...time.Time) predicate.DownloadRecord

ImportedAtNotIn applies the NotIn predicate on the "imported_at" field.

func ImportedAtNotNil

func ImportedAtNotNil() predicate.DownloadRecord

ImportedAtNotNil applies the NotNil predicate on the "imported_at" field.

func IndexerName

func IndexerName(v string) predicate.DownloadRecord

IndexerName applies equality check predicate on the "indexer_name" field. It's identical to IndexerNameEQ.

func IndexerNameContains

func IndexerNameContains(v string) predicate.DownloadRecord

IndexerNameContains applies the Contains predicate on the "indexer_name" field.

func IndexerNameContainsFold

func IndexerNameContainsFold(v string) predicate.DownloadRecord

IndexerNameContainsFold applies the ContainsFold predicate on the "indexer_name" field.

func IndexerNameEQ

func IndexerNameEQ(v string) predicate.DownloadRecord

IndexerNameEQ applies the EQ predicate on the "indexer_name" field.

func IndexerNameEqualFold

func IndexerNameEqualFold(v string) predicate.DownloadRecord

IndexerNameEqualFold applies the EqualFold predicate on the "indexer_name" field.

func IndexerNameGT

func IndexerNameGT(v string) predicate.DownloadRecord

IndexerNameGT applies the GT predicate on the "indexer_name" field.

func IndexerNameGTE

func IndexerNameGTE(v string) predicate.DownloadRecord

IndexerNameGTE applies the GTE predicate on the "indexer_name" field.

func IndexerNameHasPrefix

func IndexerNameHasPrefix(v string) predicate.DownloadRecord

IndexerNameHasPrefix applies the HasPrefix predicate on the "indexer_name" field.

func IndexerNameHasSuffix

func IndexerNameHasSuffix(v string) predicate.DownloadRecord

IndexerNameHasSuffix applies the HasSuffix predicate on the "indexer_name" field.

func IndexerNameIn

func IndexerNameIn(vs ...string) predicate.DownloadRecord

IndexerNameIn applies the In predicate on the "indexer_name" field.

func IndexerNameIsNil

func IndexerNameIsNil() predicate.DownloadRecord

IndexerNameIsNil applies the IsNil predicate on the "indexer_name" field.

func IndexerNameLT

func IndexerNameLT(v string) predicate.DownloadRecord

IndexerNameLT applies the LT predicate on the "indexer_name" field.

func IndexerNameLTE

func IndexerNameLTE(v string) predicate.DownloadRecord

IndexerNameLTE applies the LTE predicate on the "indexer_name" field.

func IndexerNameNEQ

func IndexerNameNEQ(v string) predicate.DownloadRecord

IndexerNameNEQ applies the NEQ predicate on the "indexer_name" field.

func IndexerNameNotIn

func IndexerNameNotIn(vs ...string) predicate.DownloadRecord

IndexerNameNotIn applies the NotIn predicate on the "indexer_name" field.

func IndexerNameNotNil

func IndexerNameNotNil() predicate.DownloadRecord

IndexerNameNotNil applies the NotNil predicate on the "indexer_name" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Quality

func Quality(v string) predicate.DownloadRecord

Quality applies equality check predicate on the "quality" field. It's identical to QualityEQ.

func QualityContains

func QualityContains(v string) predicate.DownloadRecord

QualityContains applies the Contains predicate on the "quality" field.

func QualityContainsFold

func QualityContainsFold(v string) predicate.DownloadRecord

QualityContainsFold applies the ContainsFold predicate on the "quality" field.

func QualityEQ

func QualityEQ(v string) predicate.DownloadRecord

QualityEQ applies the EQ predicate on the "quality" field.

func QualityEqualFold

func QualityEqualFold(v string) predicate.DownloadRecord

QualityEqualFold applies the EqualFold predicate on the "quality" field.

func QualityGT

func QualityGT(v string) predicate.DownloadRecord

QualityGT applies the GT predicate on the "quality" field.

func QualityGTE

func QualityGTE(v string) predicate.DownloadRecord

QualityGTE applies the GTE predicate on the "quality" field.

func QualityHasPrefix

func QualityHasPrefix(v string) predicate.DownloadRecord

QualityHasPrefix applies the HasPrefix predicate on the "quality" field.

func QualityHasSuffix

func QualityHasSuffix(v string) predicate.DownloadRecord

QualityHasSuffix applies the HasSuffix predicate on the "quality" field.

func QualityIn

func QualityIn(vs ...string) predicate.DownloadRecord

QualityIn applies the In predicate on the "quality" field.

func QualityIsNil

func QualityIsNil() predicate.DownloadRecord

QualityIsNil applies the IsNil predicate on the "quality" field.

func QualityLT

func QualityLT(v string) predicate.DownloadRecord

QualityLT applies the LT predicate on the "quality" field.

func QualityLTE

func QualityLTE(v string) predicate.DownloadRecord

QualityLTE applies the LTE predicate on the "quality" field.

func QualityNEQ

func QualityNEQ(v string) predicate.DownloadRecord

QualityNEQ applies the NEQ predicate on the "quality" field.

func QualityNotIn

func QualityNotIn(vs ...string) predicate.DownloadRecord

QualityNotIn applies the NotIn predicate on the "quality" field.

func QualityNotNil

func QualityNotNil() predicate.DownloadRecord

QualityNotNil applies the NotNil predicate on the "quality" field.

func ReleaseGroup

func ReleaseGroup(v string) predicate.DownloadRecord

ReleaseGroup applies equality check predicate on the "release_group" field. It's identical to ReleaseGroupEQ.

func ReleaseGroupContains

func ReleaseGroupContains(v string) predicate.DownloadRecord

ReleaseGroupContains applies the Contains predicate on the "release_group" field.

func ReleaseGroupContainsFold

func ReleaseGroupContainsFold(v string) predicate.DownloadRecord

ReleaseGroupContainsFold applies the ContainsFold predicate on the "release_group" field.

func ReleaseGroupEQ

func ReleaseGroupEQ(v string) predicate.DownloadRecord

ReleaseGroupEQ applies the EQ predicate on the "release_group" field.

func ReleaseGroupEqualFold

func ReleaseGroupEqualFold(v string) predicate.DownloadRecord

ReleaseGroupEqualFold applies the EqualFold predicate on the "release_group" field.

func ReleaseGroupGT

func ReleaseGroupGT(v string) predicate.DownloadRecord

ReleaseGroupGT applies the GT predicate on the "release_group" field.

func ReleaseGroupGTE

func ReleaseGroupGTE(v string) predicate.DownloadRecord

ReleaseGroupGTE applies the GTE predicate on the "release_group" field.

func ReleaseGroupHasPrefix

func ReleaseGroupHasPrefix(v string) predicate.DownloadRecord

ReleaseGroupHasPrefix applies the HasPrefix predicate on the "release_group" field.

func ReleaseGroupHasSuffix

func ReleaseGroupHasSuffix(v string) predicate.DownloadRecord

ReleaseGroupHasSuffix applies the HasSuffix predicate on the "release_group" field.

func ReleaseGroupIn

func ReleaseGroupIn(vs ...string) predicate.DownloadRecord

ReleaseGroupIn applies the In predicate on the "release_group" field.

func ReleaseGroupIsNil

func ReleaseGroupIsNil() predicate.DownloadRecord

ReleaseGroupIsNil applies the IsNil predicate on the "release_group" field.

func ReleaseGroupLT

func ReleaseGroupLT(v string) predicate.DownloadRecord

ReleaseGroupLT applies the LT predicate on the "release_group" field.

func ReleaseGroupLTE

func ReleaseGroupLTE(v string) predicate.DownloadRecord

ReleaseGroupLTE applies the LTE predicate on the "release_group" field.

func ReleaseGroupNEQ

func ReleaseGroupNEQ(v string) predicate.DownloadRecord

ReleaseGroupNEQ applies the NEQ predicate on the "release_group" field.

func ReleaseGroupNotIn

func ReleaseGroupNotIn(vs ...string) predicate.DownloadRecord

ReleaseGroupNotIn applies the NotIn predicate on the "release_group" field.

func ReleaseGroupNotNil

func ReleaseGroupNotNil() predicate.DownloadRecord

ReleaseGroupNotNil applies the NotNil predicate on the "release_group" field.

func ReplaceExisting

func ReplaceExisting(v bool) predicate.DownloadRecord

ReplaceExisting applies equality check predicate on the "replace_existing" field. It's identical to ReplaceExistingEQ.

func ReplaceExistingEQ

func ReplaceExistingEQ(v bool) predicate.DownloadRecord

ReplaceExistingEQ applies the EQ predicate on the "replace_existing" field.

func ReplaceExistingNEQ

func ReplaceExistingNEQ(v bool) predicate.DownloadRecord

ReplaceExistingNEQ applies the NEQ predicate on the "replace_existing" field.

func SavePath

func SavePath(v string) predicate.DownloadRecord

SavePath applies equality check predicate on the "save_path" field. It's identical to SavePathEQ.

func SavePathContains

func SavePathContains(v string) predicate.DownloadRecord

SavePathContains applies the Contains predicate on the "save_path" field.

func SavePathContainsFold

func SavePathContainsFold(v string) predicate.DownloadRecord

SavePathContainsFold applies the ContainsFold predicate on the "save_path" field.

func SavePathEQ

func SavePathEQ(v string) predicate.DownloadRecord

SavePathEQ applies the EQ predicate on the "save_path" field.

func SavePathEqualFold

func SavePathEqualFold(v string) predicate.DownloadRecord

SavePathEqualFold applies the EqualFold predicate on the "save_path" field.

func SavePathGT

func SavePathGT(v string) predicate.DownloadRecord

SavePathGT applies the GT predicate on the "save_path" field.

func SavePathGTE

func SavePathGTE(v string) predicate.DownloadRecord

SavePathGTE applies the GTE predicate on the "save_path" field.

func SavePathHasPrefix

func SavePathHasPrefix(v string) predicate.DownloadRecord

SavePathHasPrefix applies the HasPrefix predicate on the "save_path" field.

func SavePathHasSuffix

func SavePathHasSuffix(v string) predicate.DownloadRecord

SavePathHasSuffix applies the HasSuffix predicate on the "save_path" field.

func SavePathIn

func SavePathIn(vs ...string) predicate.DownloadRecord

SavePathIn applies the In predicate on the "save_path" field.

func SavePathIsNil

func SavePathIsNil() predicate.DownloadRecord

SavePathIsNil applies the IsNil predicate on the "save_path" field.

func SavePathLT

func SavePathLT(v string) predicate.DownloadRecord

SavePathLT applies the LT predicate on the "save_path" field.

func SavePathLTE

func SavePathLTE(v string) predicate.DownloadRecord

SavePathLTE applies the LTE predicate on the "save_path" field.

func SavePathNEQ

func SavePathNEQ(v string) predicate.DownloadRecord

SavePathNEQ applies the NEQ predicate on the "save_path" field.

func SavePathNotIn

func SavePathNotIn(vs ...string) predicate.DownloadRecord

SavePathNotIn applies the NotIn predicate on the "save_path" field.

func SavePathNotNil

func SavePathNotNil() predicate.DownloadRecord

SavePathNotNil applies the NotNil predicate on the "save_path" field.

func Size

Size applies equality check predicate on the "size" field. It's identical to SizeEQ.

func SizeEQ

func SizeEQ(v int64) predicate.DownloadRecord

SizeEQ applies the EQ predicate on the "size" field.

func SizeGT

func SizeGT(v int64) predicate.DownloadRecord

SizeGT applies the GT predicate on the "size" field.

func SizeGTE

func SizeGTE(v int64) predicate.DownloadRecord

SizeGTE applies the GTE predicate on the "size" field.

func SizeIn

func SizeIn(vs ...int64) predicate.DownloadRecord

SizeIn applies the In predicate on the "size" field.

func SizeIsNil

func SizeIsNil() predicate.DownloadRecord

SizeIsNil applies the IsNil predicate on the "size" field.

func SizeLT

func SizeLT(v int64) predicate.DownloadRecord

SizeLT applies the LT predicate on the "size" field.

func SizeLTE

func SizeLTE(v int64) predicate.DownloadRecord

SizeLTE applies the LTE predicate on the "size" field.

func SizeNEQ

func SizeNEQ(v int64) predicate.DownloadRecord

SizeNEQ applies the NEQ predicate on the "size" field.

func SizeNotIn

func SizeNotIn(vs ...int64) predicate.DownloadRecord

SizeNotIn applies the NotIn predicate on the "size" field.

func SizeNotNil

func SizeNotNil() predicate.DownloadRecord

SizeNotNil applies the NotNil predicate on the "size" field.

func StatusEQ

func StatusEQ(v Status) predicate.DownloadRecord

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.DownloadRecord

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.DownloadRecord

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.DownloadRecord

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func Title

Title applies equality check predicate on the "title" field. It's identical to TitleEQ.

func TitleContains

func TitleContains(v string) predicate.DownloadRecord

TitleContains applies the Contains predicate on the "title" field.

func TitleContainsFold

func TitleContainsFold(v string) predicate.DownloadRecord

TitleContainsFold applies the ContainsFold predicate on the "title" field.

func TitleEQ

func TitleEQ(v string) predicate.DownloadRecord

TitleEQ applies the EQ predicate on the "title" field.

func TitleEqualFold

func TitleEqualFold(v string) predicate.DownloadRecord

TitleEqualFold applies the EqualFold predicate on the "title" field.

func TitleGT

func TitleGT(v string) predicate.DownloadRecord

TitleGT applies the GT predicate on the "title" field.

func TitleGTE

func TitleGTE(v string) predicate.DownloadRecord

TitleGTE applies the GTE predicate on the "title" field.

func TitleHasPrefix

func TitleHasPrefix(v string) predicate.DownloadRecord

TitleHasPrefix applies the HasPrefix predicate on the "title" field.

func TitleHasSuffix

func TitleHasSuffix(v string) predicate.DownloadRecord

TitleHasSuffix applies the HasSuffix predicate on the "title" field.

func TitleIn

func TitleIn(vs ...string) predicate.DownloadRecord

TitleIn applies the In predicate on the "title" field.

func TitleLT

func TitleLT(v string) predicate.DownloadRecord

TitleLT applies the LT predicate on the "title" field.

func TitleLTE

func TitleLTE(v string) predicate.DownloadRecord

TitleLTE applies the LTE predicate on the "title" field.

func TitleNEQ

func TitleNEQ(v string) predicate.DownloadRecord

TitleNEQ applies the NEQ predicate on the "title" field.

func TitleNotIn

func TitleNotIn(vs ...string) predicate.DownloadRecord

TitleNotIn applies the NotIn predicate on the "title" field.

func TorrentHash

func TorrentHash(v string) predicate.DownloadRecord

TorrentHash applies equality check predicate on the "torrent_hash" field. It's identical to TorrentHashEQ.

func TorrentHashContains

func TorrentHashContains(v string) predicate.DownloadRecord

TorrentHashContains applies the Contains predicate on the "torrent_hash" field.

func TorrentHashContainsFold

func TorrentHashContainsFold(v string) predicate.DownloadRecord

TorrentHashContainsFold applies the ContainsFold predicate on the "torrent_hash" field.

func TorrentHashEQ

func TorrentHashEQ(v string) predicate.DownloadRecord

TorrentHashEQ applies the EQ predicate on the "torrent_hash" field.

func TorrentHashEqualFold

func TorrentHashEqualFold(v string) predicate.DownloadRecord

TorrentHashEqualFold applies the EqualFold predicate on the "torrent_hash" field.

func TorrentHashGT

func TorrentHashGT(v string) predicate.DownloadRecord

TorrentHashGT applies the GT predicate on the "torrent_hash" field.

func TorrentHashGTE

func TorrentHashGTE(v string) predicate.DownloadRecord

TorrentHashGTE applies the GTE predicate on the "torrent_hash" field.

func TorrentHashHasPrefix

func TorrentHashHasPrefix(v string) predicate.DownloadRecord

TorrentHashHasPrefix applies the HasPrefix predicate on the "torrent_hash" field.

func TorrentHashHasSuffix

func TorrentHashHasSuffix(v string) predicate.DownloadRecord

TorrentHashHasSuffix applies the HasSuffix predicate on the "torrent_hash" field.

func TorrentHashIn

func TorrentHashIn(vs ...string) predicate.DownloadRecord

TorrentHashIn applies the In predicate on the "torrent_hash" field.

func TorrentHashIsNil

func TorrentHashIsNil() predicate.DownloadRecord

TorrentHashIsNil applies the IsNil predicate on the "torrent_hash" field.

func TorrentHashLT

func TorrentHashLT(v string) predicate.DownloadRecord

TorrentHashLT applies the LT predicate on the "torrent_hash" field.

func TorrentHashLTE

func TorrentHashLTE(v string) predicate.DownloadRecord

TorrentHashLTE applies the LTE predicate on the "torrent_hash" field.

func TorrentHashNEQ

func TorrentHashNEQ(v string) predicate.DownloadRecord

TorrentHashNEQ applies the NEQ predicate on the "torrent_hash" field.

func TorrentHashNotIn

func TorrentHashNotIn(vs ...string) predicate.DownloadRecord

TorrentHashNotIn applies the NotIn predicate on the "torrent_hash" field.

func TorrentHashNotNil

func TorrentHashNotNil() predicate.DownloadRecord

TorrentHashNotNil applies the NotNil predicate on the "torrent_hash" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.DownloadRecord

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.DownloadRecord

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.DownloadRecord

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.DownloadRecord

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.DownloadRecord

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.DownloadRecord

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.DownloadRecord

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.DownloadRecord

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.DownloadRecord

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the DownloadRecord queries.

func ByCreateTime

func ByCreateTime(opts ...sql.OrderTermOption) OrderOption

ByCreateTime orders the results by the create_time field.

func ByDownloadClientName

func ByDownloadClientName(opts ...sql.OrderTermOption) OrderOption

ByDownloadClientName orders the results by the download_client_name field.

func ByEpisodeField

func ByEpisodeField(field string, opts ...sql.OrderTermOption) OrderOption

ByEpisodeField orders the results by episode field.

func ByFailureReason

func ByFailureReason(opts ...sql.OrderTermOption) OrderOption

ByFailureReason orders the results by the failure_reason field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByImportAttempts

func ByImportAttempts(opts ...sql.OrderTermOption) OrderOption

ByImportAttempts orders the results by the import_attempts field.

func ByImportedAt

func ByImportedAt(opts ...sql.OrderTermOption) OrderOption

ByImportedAt orders the results by the imported_at field.

func ByIndexerName

func ByIndexerName(opts ...sql.OrderTermOption) OrderOption

ByIndexerName orders the results by the indexer_name field.

func ByMovieField

func ByMovieField(field string, opts ...sql.OrderTermOption) OrderOption

ByMovieField orders the results by movie field.

func ByQuality

func ByQuality(opts ...sql.OrderTermOption) OrderOption

ByQuality orders the results by the quality field.

func ByReleaseGroup

func ByReleaseGroup(opts ...sql.OrderTermOption) OrderOption

ByReleaseGroup orders the results by the release_group field.

func ByReplaceExisting

func ByReplaceExisting(opts ...sql.OrderTermOption) OrderOption

ByReplaceExisting orders the results by the replace_existing field.

func BySavePath

func BySavePath(opts ...sql.OrderTermOption) OrderOption

BySavePath orders the results by the save_path field.

func BySize

func BySize(opts ...sql.OrderTermOption) OrderOption

BySize orders the results by the size field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByTitle

func ByTitle(opts ...sql.OrderTermOption) OrderOption

ByTitle orders the results by the title field.

func ByTorrentHash

func ByTorrentHash(opts ...sql.OrderTermOption) OrderOption

ByTorrentHash orders the results by the torrent_hash field.

func ByUpdateTime

func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption

ByUpdateTime orders the results by the update_time field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusDownloading Status = "downloading"
	StatusImporting   Status = "importing"
	StatusCompleted   Status = "completed"
	StatusFailed      Status = "failed"
	StatusPending     Status = "pending"
	StatusDismissed   Status = "dismissed"
)

Status values.

func (Status) String

func (s Status) String() string

Jump to