movie

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the movie type in the database.
	Label = "movie"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldTitle holds the string denoting the title field in the database.
	FieldTitle = "title"
	// FieldOriginalTitle holds the string denoting the original_title field in the database.
	FieldOriginalTitle = "original_title"
	// FieldYear holds the string denoting the year field in the database.
	FieldYear = "year"
	// FieldOverview holds the string denoting the overview field in the database.
	FieldOverview = "overview"
	// FieldRuntime holds the string denoting the runtime field in the database.
	FieldRuntime = "runtime"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldMonitored holds the string denoting the monitored field in the database.
	FieldMonitored = "monitored"
	// FieldTmdbID holds the string denoting the tmdb_id field in the database.
	FieldTmdbID = "tmdb_id"
	// FieldLastSearchAt holds the string denoting the last_search_at field in the database.
	FieldLastSearchAt = "last_search_at"
	// FieldDigitalReleaseDate holds the string denoting the digital_release_date field in the database.
	FieldDigitalReleaseDate = "digital_release_date"
	// FieldGrabFailures holds the string denoting the grab_failures field in the database.
	FieldGrabFailures = "grab_failures"
	// FieldFailureReason holds the string denoting the failure_reason field in the database.
	FieldFailureReason = "failure_reason"
	// FieldQualityProfile holds the string denoting the quality_profile field in the database.
	FieldQualityProfile = "quality_profile"
	// EdgeDownloadRecords holds the string denoting the download_records edge name in mutations.
	EdgeDownloadRecords = "download_records"
	// EdgeMediaFiles holds the string denoting the media_files edge name in mutations.
	EdgeMediaFiles = "media_files"
	// EdgeEvents holds the string denoting the events edge name in mutations.
	EdgeEvents = "events"
	// Table holds the table name of the movie in the database.
	Table = "movies"
	// DownloadRecordsTable is the table that holds the download_records relation/edge.
	DownloadRecordsTable = "download_records"
	// DownloadRecordsInverseTable is the table name for the DownloadRecord entity.
	// It exists in this package in order to avoid circular dependency with the "downloadrecord" package.
	DownloadRecordsInverseTable = "download_records"
	// DownloadRecordsColumn is the table column denoting the download_records relation/edge.
	DownloadRecordsColumn = "movie_download_records"
	// MediaFilesTable is the table that holds the media_files relation/edge.
	MediaFilesTable = "media_files"
	// MediaFilesInverseTable is the table name for the MediaFile entity.
	// It exists in this package in order to avoid circular dependency with the "mediafile" package.
	MediaFilesInverseTable = "media_files"
	// MediaFilesColumn is the table column denoting the media_files relation/edge.
	MediaFilesColumn = "movie_media_files"
	// EventsTable is the table that holds the events relation/edge.
	EventsTable = "movie_events"
	// EventsInverseTable is the table name for the MovieEvent entity.
	// It exists in this package in order to avoid circular dependency with the "movieevent" package.
	EventsInverseTable = "movie_events"
	// EventsColumn is the table column denoting the events relation/edge.
	EventsColumn = "movie_events"
)
const DefaultStatus = StatusWanted

StatusWanted is the default value of the Status enum.

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// TitleValidator is a validator for the "title" field. It is called by the builders before save.
	TitleValidator func(string) error
	// OriginalTitleValidator is a validator for the "original_title" field. It is called by the builders before save.
	OriginalTitleValidator func(string) error
	// DefaultRuntime holds the default value on creation for the "runtime" field.
	DefaultRuntime uint16
	// DefaultMonitored holds the default value on creation for the "monitored" field.
	DefaultMonitored bool
	// DefaultGrabFailures holds the default value on creation for the "grab_failures" field.
	DefaultGrabFailures uint8
)

Columns holds all SQL columns for movie fields.

Functions

func And

func And(predicates ...predicate.Movie) predicate.Movie

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.Movie

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.Movie

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.Movie

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.Movie

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.Movie

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.Movie

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.Movie

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.Movie

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.Movie

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func DigitalReleaseDate

func DigitalReleaseDate(v time.Time) predicate.Movie

DigitalReleaseDate applies equality check predicate on the "digital_release_date" field. It's identical to DigitalReleaseDateEQ.

func DigitalReleaseDateEQ

func DigitalReleaseDateEQ(v time.Time) predicate.Movie

DigitalReleaseDateEQ applies the EQ predicate on the "digital_release_date" field.

func DigitalReleaseDateGT

func DigitalReleaseDateGT(v time.Time) predicate.Movie

DigitalReleaseDateGT applies the GT predicate on the "digital_release_date" field.

func DigitalReleaseDateGTE

func DigitalReleaseDateGTE(v time.Time) predicate.Movie

DigitalReleaseDateGTE applies the GTE predicate on the "digital_release_date" field.

func DigitalReleaseDateIn

func DigitalReleaseDateIn(vs ...time.Time) predicate.Movie

DigitalReleaseDateIn applies the In predicate on the "digital_release_date" field.

func DigitalReleaseDateIsNil

func DigitalReleaseDateIsNil() predicate.Movie

DigitalReleaseDateIsNil applies the IsNil predicate on the "digital_release_date" field.

func DigitalReleaseDateLT

func DigitalReleaseDateLT(v time.Time) predicate.Movie

DigitalReleaseDateLT applies the LT predicate on the "digital_release_date" field.

func DigitalReleaseDateLTE

func DigitalReleaseDateLTE(v time.Time) predicate.Movie

DigitalReleaseDateLTE applies the LTE predicate on the "digital_release_date" field.

func DigitalReleaseDateNEQ

func DigitalReleaseDateNEQ(v time.Time) predicate.Movie

DigitalReleaseDateNEQ applies the NEQ predicate on the "digital_release_date" field.

func DigitalReleaseDateNotIn

func DigitalReleaseDateNotIn(vs ...time.Time) predicate.Movie

DigitalReleaseDateNotIn applies the NotIn predicate on the "digital_release_date" field.

func DigitalReleaseDateNotNil

func DigitalReleaseDateNotNil() predicate.Movie

DigitalReleaseDateNotNil applies the NotNil predicate on the "digital_release_date" field.

func FailureReason

func FailureReason(v string) predicate.Movie

FailureReason applies equality check predicate on the "failure_reason" field. It's identical to FailureReasonEQ.

func FailureReasonContains

func FailureReasonContains(v string) predicate.Movie

FailureReasonContains applies the Contains predicate on the "failure_reason" field.

func FailureReasonContainsFold

func FailureReasonContainsFold(v string) predicate.Movie

FailureReasonContainsFold applies the ContainsFold predicate on the "failure_reason" field.

func FailureReasonEQ

func FailureReasonEQ(v string) predicate.Movie

FailureReasonEQ applies the EQ predicate on the "failure_reason" field.

func FailureReasonEqualFold

func FailureReasonEqualFold(v string) predicate.Movie

FailureReasonEqualFold applies the EqualFold predicate on the "failure_reason" field.

func FailureReasonGT

func FailureReasonGT(v string) predicate.Movie

FailureReasonGT applies the GT predicate on the "failure_reason" field.

func FailureReasonGTE

func FailureReasonGTE(v string) predicate.Movie

FailureReasonGTE applies the GTE predicate on the "failure_reason" field.

func FailureReasonHasPrefix

func FailureReasonHasPrefix(v string) predicate.Movie

FailureReasonHasPrefix applies the HasPrefix predicate on the "failure_reason" field.

func FailureReasonHasSuffix

func FailureReasonHasSuffix(v string) predicate.Movie

FailureReasonHasSuffix applies the HasSuffix predicate on the "failure_reason" field.

func FailureReasonIn

func FailureReasonIn(vs ...string) predicate.Movie

FailureReasonIn applies the In predicate on the "failure_reason" field.

func FailureReasonIsNil

func FailureReasonIsNil() predicate.Movie

FailureReasonIsNil applies the IsNil predicate on the "failure_reason" field.

func FailureReasonLT

func FailureReasonLT(v string) predicate.Movie

FailureReasonLT applies the LT predicate on the "failure_reason" field.

func FailureReasonLTE

func FailureReasonLTE(v string) predicate.Movie

FailureReasonLTE applies the LTE predicate on the "failure_reason" field.

func FailureReasonNEQ

func FailureReasonNEQ(v string) predicate.Movie

FailureReasonNEQ applies the NEQ predicate on the "failure_reason" field.

func FailureReasonNotIn

func FailureReasonNotIn(vs ...string) predicate.Movie

FailureReasonNotIn applies the NotIn predicate on the "failure_reason" field.

func FailureReasonNotNil

func FailureReasonNotNil() predicate.Movie

FailureReasonNotNil applies the NotNil predicate on the "failure_reason" field.

func GrabFailures

func GrabFailures(v uint8) predicate.Movie

GrabFailures applies equality check predicate on the "grab_failures" field. It's identical to GrabFailuresEQ.

func GrabFailuresEQ

func GrabFailuresEQ(v uint8) predicate.Movie

GrabFailuresEQ applies the EQ predicate on the "grab_failures" field.

func GrabFailuresGT

func GrabFailuresGT(v uint8) predicate.Movie

GrabFailuresGT applies the GT predicate on the "grab_failures" field.

func GrabFailuresGTE

func GrabFailuresGTE(v uint8) predicate.Movie

GrabFailuresGTE applies the GTE predicate on the "grab_failures" field.

func GrabFailuresIn

func GrabFailuresIn(vs ...uint8) predicate.Movie

GrabFailuresIn applies the In predicate on the "grab_failures" field.

func GrabFailuresLT

func GrabFailuresLT(v uint8) predicate.Movie

GrabFailuresLT applies the LT predicate on the "grab_failures" field.

func GrabFailuresLTE

func GrabFailuresLTE(v uint8) predicate.Movie

GrabFailuresLTE applies the LTE predicate on the "grab_failures" field.

func GrabFailuresNEQ

func GrabFailuresNEQ(v uint8) predicate.Movie

GrabFailuresNEQ applies the NEQ predicate on the "grab_failures" field.

func GrabFailuresNotIn

func GrabFailuresNotIn(vs ...uint8) predicate.Movie

GrabFailuresNotIn applies the NotIn predicate on the "grab_failures" field.

func HasDownloadRecords

func HasDownloadRecords() predicate.Movie

HasDownloadRecords applies the HasEdge predicate on the "download_records" edge.

func HasDownloadRecordsWith

func HasDownloadRecordsWith(preds ...predicate.DownloadRecord) predicate.Movie

HasDownloadRecordsWith applies the HasEdge predicate on the "download_records" edge with a given conditions (other predicates).

func HasEvents

func HasEvents() predicate.Movie

HasEvents applies the HasEdge predicate on the "events" edge.

func HasEventsWith

func HasEventsWith(preds ...predicate.MovieEvent) predicate.Movie

HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).

func HasMediaFiles

func HasMediaFiles() predicate.Movie

HasMediaFiles applies the HasEdge predicate on the "media_files" edge.

func HasMediaFilesWith

func HasMediaFilesWith(preds ...predicate.MediaFile) predicate.Movie

HasMediaFilesWith applies the HasEdge predicate on the "media_files" edge with a given conditions (other predicates).

func ID

func ID(id uint32) predicate.Movie

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uint32) predicate.Movie

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uint32) predicate.Movie

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uint32) predicate.Movie

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint32) predicate.Movie

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uint32) predicate.Movie

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uint32) predicate.Movie

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uint32) predicate.Movie

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint32) predicate.Movie

IDNotIn applies the NotIn predicate on the ID field.

func LastSearchAt

func LastSearchAt(v time.Time) predicate.Movie

LastSearchAt applies equality check predicate on the "last_search_at" field. It's identical to LastSearchAtEQ.

func LastSearchAtEQ

func LastSearchAtEQ(v time.Time) predicate.Movie

LastSearchAtEQ applies the EQ predicate on the "last_search_at" field.

func LastSearchAtGT

func LastSearchAtGT(v time.Time) predicate.Movie

LastSearchAtGT applies the GT predicate on the "last_search_at" field.

func LastSearchAtGTE

func LastSearchAtGTE(v time.Time) predicate.Movie

LastSearchAtGTE applies the GTE predicate on the "last_search_at" field.

func LastSearchAtIn

func LastSearchAtIn(vs ...time.Time) predicate.Movie

LastSearchAtIn applies the In predicate on the "last_search_at" field.

func LastSearchAtIsNil

func LastSearchAtIsNil() predicate.Movie

LastSearchAtIsNil applies the IsNil predicate on the "last_search_at" field.

func LastSearchAtLT

func LastSearchAtLT(v time.Time) predicate.Movie

LastSearchAtLT applies the LT predicate on the "last_search_at" field.

func LastSearchAtLTE

func LastSearchAtLTE(v time.Time) predicate.Movie

LastSearchAtLTE applies the LTE predicate on the "last_search_at" field.

func LastSearchAtNEQ

func LastSearchAtNEQ(v time.Time) predicate.Movie

LastSearchAtNEQ applies the NEQ predicate on the "last_search_at" field.

func LastSearchAtNotIn

func LastSearchAtNotIn(vs ...time.Time) predicate.Movie

LastSearchAtNotIn applies the NotIn predicate on the "last_search_at" field.

func LastSearchAtNotNil

func LastSearchAtNotNil() predicate.Movie

LastSearchAtNotNil applies the NotNil predicate on the "last_search_at" field.

func Monitored

func Monitored(v bool) predicate.Movie

Monitored applies equality check predicate on the "monitored" field. It's identical to MonitoredEQ.

func MonitoredEQ

func MonitoredEQ(v bool) predicate.Movie

MonitoredEQ applies the EQ predicate on the "monitored" field.

func MonitoredNEQ

func MonitoredNEQ(v bool) predicate.Movie

MonitoredNEQ applies the NEQ predicate on the "monitored" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Movie) predicate.Movie

Or groups predicates with the OR operator between them.

func OriginalTitle

func OriginalTitle(v string) predicate.Movie

OriginalTitle applies equality check predicate on the "original_title" field. It's identical to OriginalTitleEQ.

func OriginalTitleContains

func OriginalTitleContains(v string) predicate.Movie

OriginalTitleContains applies the Contains predicate on the "original_title" field.

func OriginalTitleContainsFold

func OriginalTitleContainsFold(v string) predicate.Movie

OriginalTitleContainsFold applies the ContainsFold predicate on the "original_title" field.

func OriginalTitleEQ

func OriginalTitleEQ(v string) predicate.Movie

OriginalTitleEQ applies the EQ predicate on the "original_title" field.

func OriginalTitleEqualFold

func OriginalTitleEqualFold(v string) predicate.Movie

OriginalTitleEqualFold applies the EqualFold predicate on the "original_title" field.

func OriginalTitleGT

func OriginalTitleGT(v string) predicate.Movie

OriginalTitleGT applies the GT predicate on the "original_title" field.

func OriginalTitleGTE

func OriginalTitleGTE(v string) predicate.Movie

OriginalTitleGTE applies the GTE predicate on the "original_title" field.

func OriginalTitleHasPrefix

func OriginalTitleHasPrefix(v string) predicate.Movie

OriginalTitleHasPrefix applies the HasPrefix predicate on the "original_title" field.

func OriginalTitleHasSuffix

func OriginalTitleHasSuffix(v string) predicate.Movie

OriginalTitleHasSuffix applies the HasSuffix predicate on the "original_title" field.

func OriginalTitleIn

func OriginalTitleIn(vs ...string) predicate.Movie

OriginalTitleIn applies the In predicate on the "original_title" field.

func OriginalTitleLT

func OriginalTitleLT(v string) predicate.Movie

OriginalTitleLT applies the LT predicate on the "original_title" field.

func OriginalTitleLTE

func OriginalTitleLTE(v string) predicate.Movie

OriginalTitleLTE applies the LTE predicate on the "original_title" field.

func OriginalTitleNEQ

func OriginalTitleNEQ(v string) predicate.Movie

OriginalTitleNEQ applies the NEQ predicate on the "original_title" field.

func OriginalTitleNotIn

func OriginalTitleNotIn(vs ...string) predicate.Movie

OriginalTitleNotIn applies the NotIn predicate on the "original_title" field.

func Overview

func Overview(v string) predicate.Movie

Overview applies equality check predicate on the "overview" field. It's identical to OverviewEQ.

func OverviewContains

func OverviewContains(v string) predicate.Movie

OverviewContains applies the Contains predicate on the "overview" field.

func OverviewContainsFold

func OverviewContainsFold(v string) predicate.Movie

OverviewContainsFold applies the ContainsFold predicate on the "overview" field.

func OverviewEQ

func OverviewEQ(v string) predicate.Movie

OverviewEQ applies the EQ predicate on the "overview" field.

func OverviewEqualFold

func OverviewEqualFold(v string) predicate.Movie

OverviewEqualFold applies the EqualFold predicate on the "overview" field.

func OverviewGT

func OverviewGT(v string) predicate.Movie

OverviewGT applies the GT predicate on the "overview" field.

func OverviewGTE

func OverviewGTE(v string) predicate.Movie

OverviewGTE applies the GTE predicate on the "overview" field.

func OverviewHasPrefix

func OverviewHasPrefix(v string) predicate.Movie

OverviewHasPrefix applies the HasPrefix predicate on the "overview" field.

func OverviewHasSuffix

func OverviewHasSuffix(v string) predicate.Movie

OverviewHasSuffix applies the HasSuffix predicate on the "overview" field.

func OverviewIn

func OverviewIn(vs ...string) predicate.Movie

OverviewIn applies the In predicate on the "overview" field.

func OverviewIsNil

func OverviewIsNil() predicate.Movie

OverviewIsNil applies the IsNil predicate on the "overview" field.

func OverviewLT

func OverviewLT(v string) predicate.Movie

OverviewLT applies the LT predicate on the "overview" field.

func OverviewLTE

func OverviewLTE(v string) predicate.Movie

OverviewLTE applies the LTE predicate on the "overview" field.

func OverviewNEQ

func OverviewNEQ(v string) predicate.Movie

OverviewNEQ applies the NEQ predicate on the "overview" field.

func OverviewNotIn

func OverviewNotIn(vs ...string) predicate.Movie

OverviewNotIn applies the NotIn predicate on the "overview" field.

func OverviewNotNil

func OverviewNotNil() predicate.Movie

OverviewNotNil applies the NotNil predicate on the "overview" field.

func QualityProfile

func QualityProfile(v string) predicate.Movie

QualityProfile applies equality check predicate on the "quality_profile" field. It's identical to QualityProfileEQ.

func QualityProfileContains

func QualityProfileContains(v string) predicate.Movie

QualityProfileContains applies the Contains predicate on the "quality_profile" field.

func QualityProfileContainsFold

func QualityProfileContainsFold(v string) predicate.Movie

QualityProfileContainsFold applies the ContainsFold predicate on the "quality_profile" field.

func QualityProfileEQ

func QualityProfileEQ(v string) predicate.Movie

QualityProfileEQ applies the EQ predicate on the "quality_profile" field.

func QualityProfileEqualFold

func QualityProfileEqualFold(v string) predicate.Movie

QualityProfileEqualFold applies the EqualFold predicate on the "quality_profile" field.

func QualityProfileGT

func QualityProfileGT(v string) predicate.Movie

QualityProfileGT applies the GT predicate on the "quality_profile" field.

func QualityProfileGTE

func QualityProfileGTE(v string) predicate.Movie

QualityProfileGTE applies the GTE predicate on the "quality_profile" field.

func QualityProfileHasPrefix

func QualityProfileHasPrefix(v string) predicate.Movie

QualityProfileHasPrefix applies the HasPrefix predicate on the "quality_profile" field.

func QualityProfileHasSuffix

func QualityProfileHasSuffix(v string) predicate.Movie

QualityProfileHasSuffix applies the HasSuffix predicate on the "quality_profile" field.

func QualityProfileIn

func QualityProfileIn(vs ...string) predicate.Movie

QualityProfileIn applies the In predicate on the "quality_profile" field.

func QualityProfileIsNil

func QualityProfileIsNil() predicate.Movie

QualityProfileIsNil applies the IsNil predicate on the "quality_profile" field.

func QualityProfileLT

func QualityProfileLT(v string) predicate.Movie

QualityProfileLT applies the LT predicate on the "quality_profile" field.

func QualityProfileLTE

func QualityProfileLTE(v string) predicate.Movie

QualityProfileLTE applies the LTE predicate on the "quality_profile" field.

func QualityProfileNEQ

func QualityProfileNEQ(v string) predicate.Movie

QualityProfileNEQ applies the NEQ predicate on the "quality_profile" field.

func QualityProfileNotIn

func QualityProfileNotIn(vs ...string) predicate.Movie

QualityProfileNotIn applies the NotIn predicate on the "quality_profile" field.

func QualityProfileNotNil

func QualityProfileNotNil() predicate.Movie

QualityProfileNotNil applies the NotNil predicate on the "quality_profile" field.

func Runtime

func Runtime(v uint16) predicate.Movie

Runtime applies equality check predicate on the "runtime" field. It's identical to RuntimeEQ.

func RuntimeEQ

func RuntimeEQ(v uint16) predicate.Movie

RuntimeEQ applies the EQ predicate on the "runtime" field.

func RuntimeGT

func RuntimeGT(v uint16) predicate.Movie

RuntimeGT applies the GT predicate on the "runtime" field.

func RuntimeGTE

func RuntimeGTE(v uint16) predicate.Movie

RuntimeGTE applies the GTE predicate on the "runtime" field.

func RuntimeIn

func RuntimeIn(vs ...uint16) predicate.Movie

RuntimeIn applies the In predicate on the "runtime" field.

func RuntimeIsNil

func RuntimeIsNil() predicate.Movie

RuntimeIsNil applies the IsNil predicate on the "runtime" field.

func RuntimeLT

func RuntimeLT(v uint16) predicate.Movie

RuntimeLT applies the LT predicate on the "runtime" field.

func RuntimeLTE

func RuntimeLTE(v uint16) predicate.Movie

RuntimeLTE applies the LTE predicate on the "runtime" field.

func RuntimeNEQ

func RuntimeNEQ(v uint16) predicate.Movie

RuntimeNEQ applies the NEQ predicate on the "runtime" field.

func RuntimeNotIn

func RuntimeNotIn(vs ...uint16) predicate.Movie

RuntimeNotIn applies the NotIn predicate on the "runtime" field.

func RuntimeNotNil

func RuntimeNotNil() predicate.Movie

RuntimeNotNil applies the NotNil predicate on the "runtime" field.

func StatusEQ

func StatusEQ(v Status) predicate.Movie

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...Status) predicate.Movie

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v Status) predicate.Movie

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...Status) predicate.Movie

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s Status) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func Title

func Title(v string) predicate.Movie

Title applies equality check predicate on the "title" field. It's identical to TitleEQ.

func TitleContains

func TitleContains(v string) predicate.Movie

TitleContains applies the Contains predicate on the "title" field.

func TitleContainsFold

func TitleContainsFold(v string) predicate.Movie

TitleContainsFold applies the ContainsFold predicate on the "title" field.

func TitleEQ

func TitleEQ(v string) predicate.Movie

TitleEQ applies the EQ predicate on the "title" field.

func TitleEqualFold

func TitleEqualFold(v string) predicate.Movie

TitleEqualFold applies the EqualFold predicate on the "title" field.

func TitleGT

func TitleGT(v string) predicate.Movie

TitleGT applies the GT predicate on the "title" field.

func TitleGTE

func TitleGTE(v string) predicate.Movie

TitleGTE applies the GTE predicate on the "title" field.

func TitleHasPrefix

func TitleHasPrefix(v string) predicate.Movie

TitleHasPrefix applies the HasPrefix predicate on the "title" field.

func TitleHasSuffix

func TitleHasSuffix(v string) predicate.Movie

TitleHasSuffix applies the HasSuffix predicate on the "title" field.

func TitleIn

func TitleIn(vs ...string) predicate.Movie

TitleIn applies the In predicate on the "title" field.

func TitleLT

func TitleLT(v string) predicate.Movie

TitleLT applies the LT predicate on the "title" field.

func TitleLTE

func TitleLTE(v string) predicate.Movie

TitleLTE applies the LTE predicate on the "title" field.

func TitleNEQ

func TitleNEQ(v string) predicate.Movie

TitleNEQ applies the NEQ predicate on the "title" field.

func TitleNotIn

func TitleNotIn(vs ...string) predicate.Movie

TitleNotIn applies the NotIn predicate on the "title" field.

func TmdbID

func TmdbID(v uint32) predicate.Movie

TmdbID applies equality check predicate on the "tmdb_id" field. It's identical to TmdbIDEQ.

func TmdbIDEQ

func TmdbIDEQ(v uint32) predicate.Movie

TmdbIDEQ applies the EQ predicate on the "tmdb_id" field.

func TmdbIDGT

func TmdbIDGT(v uint32) predicate.Movie

TmdbIDGT applies the GT predicate on the "tmdb_id" field.

func TmdbIDGTE

func TmdbIDGTE(v uint32) predicate.Movie

TmdbIDGTE applies the GTE predicate on the "tmdb_id" field.

func TmdbIDIn

func TmdbIDIn(vs ...uint32) predicate.Movie

TmdbIDIn applies the In predicate on the "tmdb_id" field.

func TmdbIDLT

func TmdbIDLT(v uint32) predicate.Movie

TmdbIDLT applies the LT predicate on the "tmdb_id" field.

func TmdbIDLTE

func TmdbIDLTE(v uint32) predicate.Movie

TmdbIDLTE applies the LTE predicate on the "tmdb_id" field.

func TmdbIDNEQ

func TmdbIDNEQ(v uint32) predicate.Movie

TmdbIDNEQ applies the NEQ predicate on the "tmdb_id" field.

func TmdbIDNotIn

func TmdbIDNotIn(vs ...uint32) predicate.Movie

TmdbIDNotIn applies the NotIn predicate on the "tmdb_id" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.Movie

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.Movie

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.Movie

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.Movie

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.Movie

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.Movie

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.Movie

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.Movie

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.Movie

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Year

func Year(v uint16) predicate.Movie

Year applies equality check predicate on the "year" field. It's identical to YearEQ.

func YearEQ

func YearEQ(v uint16) predicate.Movie

YearEQ applies the EQ predicate on the "year" field.

func YearGT

func YearGT(v uint16) predicate.Movie

YearGT applies the GT predicate on the "year" field.

func YearGTE

func YearGTE(v uint16) predicate.Movie

YearGTE applies the GTE predicate on the "year" field.

func YearIn

func YearIn(vs ...uint16) predicate.Movie

YearIn applies the In predicate on the "year" field.

func YearLT

func YearLT(v uint16) predicate.Movie

YearLT applies the LT predicate on the "year" field.

func YearLTE

func YearLTE(v uint16) predicate.Movie

YearLTE applies the LTE predicate on the "year" field.

func YearNEQ

func YearNEQ(v uint16) predicate.Movie

YearNEQ applies the NEQ predicate on the "year" field.

func YearNotIn

func YearNotIn(vs ...uint16) predicate.Movie

YearNotIn applies the NotIn predicate on the "year" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Movie queries.

func ByCreateTime

func ByCreateTime(opts ...sql.OrderTermOption) OrderOption

ByCreateTime orders the results by the create_time field.

func ByDigitalReleaseDate

func ByDigitalReleaseDate(opts ...sql.OrderTermOption) OrderOption

ByDigitalReleaseDate orders the results by the digital_release_date field.

func ByDownloadRecords

func ByDownloadRecords(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByDownloadRecords orders the results by download_records terms.

func ByDownloadRecordsCount

func ByDownloadRecordsCount(opts ...sql.OrderTermOption) OrderOption

ByDownloadRecordsCount orders the results by download_records count.

func ByEvents

func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvents orders the results by events terms.

func ByEventsCount

func ByEventsCount(opts ...sql.OrderTermOption) OrderOption

ByEventsCount orders the results by events count.

func ByFailureReason

func ByFailureReason(opts ...sql.OrderTermOption) OrderOption

ByFailureReason orders the results by the failure_reason field.

func ByGrabFailures

func ByGrabFailures(opts ...sql.OrderTermOption) OrderOption

ByGrabFailures orders the results by the grab_failures field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastSearchAt

func ByLastSearchAt(opts ...sql.OrderTermOption) OrderOption

ByLastSearchAt orders the results by the last_search_at field.

func ByMediaFiles

func ByMediaFiles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByMediaFiles orders the results by media_files terms.

func ByMediaFilesCount

func ByMediaFilesCount(opts ...sql.OrderTermOption) OrderOption

ByMediaFilesCount orders the results by media_files count.

func ByMonitored

func ByMonitored(opts ...sql.OrderTermOption) OrderOption

ByMonitored orders the results by the monitored field.

func ByOriginalTitle

func ByOriginalTitle(opts ...sql.OrderTermOption) OrderOption

ByOriginalTitle orders the results by the original_title field.

func ByOverview

func ByOverview(opts ...sql.OrderTermOption) OrderOption

ByOverview orders the results by the overview field.

func ByQualityProfile

func ByQualityProfile(opts ...sql.OrderTermOption) OrderOption

ByQualityProfile orders the results by the quality_profile field.

func ByRuntime

func ByRuntime(opts ...sql.OrderTermOption) OrderOption

ByRuntime orders the results by the runtime field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByTitle

func ByTitle(opts ...sql.OrderTermOption) OrderOption

ByTitle orders the results by the title field.

func ByTmdbID

func ByTmdbID(opts ...sql.OrderTermOption) OrderOption

ByTmdbID orders the results by the tmdb_id field.

func ByUpdateTime

func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption

ByUpdateTime orders the results by the update_time field.

func ByYear

func ByYear(opts ...sql.OrderTermOption) OrderOption

ByYear orders the results by the year field.

type Status

type Status string

Status defines the type for the "status" enum field.

const (
	StatusWanted      Status = "wanted"
	StatusDownloading Status = "downloading"
	StatusAvailable   Status = "available"
	StatusFailed      Status = "failed"
)

Status values.

func (Status) String

func (s Status) String() string

Jump to