user

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldPasswordHash holds the string denoting the password_hash field in the database.
	FieldPasswordHash = "password_hash"
	// FieldRole holds the string denoting the role field in the database.
	FieldRole = "role"
	// FieldAuthMethod holds the string denoting the auth_method field in the database.
	FieldAuthMethod = "auth_method"
	// FieldDisplayName holds the string denoting the display_name field in the database.
	FieldDisplayName = "display_name"
	// FieldFailedLoginCount holds the string denoting the failed_login_count field in the database.
	FieldFailedLoginCount = "failed_login_count"
	// FieldLastFailedLoginAt holds the string denoting the last_failed_login_at field in the database.
	FieldLastFailedLoginAt = "last_failed_login_at"
	// FieldLockedUntil holds the string denoting the locked_until field in the database.
	FieldLockedUntil = "locked_until"
	// EdgeAPIKeys holds the string denoting the api_keys edge name in mutations.
	EdgeAPIKeys = "api_keys"
	// EdgeOidcIdentities holds the string denoting the oidc_identities edge name in mutations.
	EdgeOidcIdentities = "oidc_identities"
	// EdgeRequests holds the string denoting the requests edge name in mutations.
	EdgeRequests = "requests"
	// EdgeSessions holds the string denoting the sessions edge name in mutations.
	EdgeSessions = "sessions"
	// Table holds the table name of the user in the database.
	Table = "users"
	// APIKeysTable is the table that holds the api_keys relation/edge.
	APIKeysTable = "api_keys"
	// APIKeysInverseTable is the table name for the ApiKey entity.
	// It exists in this package in order to avoid circular dependency with the "apikey" package.
	APIKeysInverseTable = "api_keys"
	// APIKeysColumn is the table column denoting the api_keys relation/edge.
	APIKeysColumn = "user_api_keys"
	// OidcIdentitiesTable is the table that holds the oidc_identities relation/edge.
	OidcIdentitiesTable = "oidc_identities"
	// OidcIdentitiesInverseTable is the table name for the OIDCIdentity entity.
	// It exists in this package in order to avoid circular dependency with the "oidcidentity" package.
	OidcIdentitiesInverseTable = "oidc_identities"
	// OidcIdentitiesColumn is the table column denoting the oidc_identities relation/edge.
	OidcIdentitiesColumn = "user_oidc_identities"
	// RequestsTable is the table that holds the requests relation/edge.
	RequestsTable = "requests"
	// RequestsInverseTable is the table name for the Request entity.
	// It exists in this package in order to avoid circular dependency with the "request" package.
	RequestsInverseTable = "requests"
	// RequestsColumn is the table column denoting the requests relation/edge.
	RequestsColumn = "user_requests"
	// SessionsTable is the table that holds the sessions relation/edge.
	SessionsTable = "sessions"
	// SessionsInverseTable is the table name for the Session entity.
	// It exists in this package in order to avoid circular dependency with the "session" package.
	SessionsInverseTable = "sessions"
	// SessionsColumn is the table column denoting the sessions relation/edge.
	SessionsColumn = "user_sessions"
)
const DefaultAuthMethod = AuthMethodLocal

AuthMethodLocal is the default value of the AuthMethod enum.

const DefaultRole = RoleMember

RoleMember is the default value of the Role enum.

Variables

var (
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// DefaultFailedLoginCount holds the default value on creation for the "failed_login_count" field.
	DefaultFailedLoginCount uint8
)

Columns holds all SQL columns for user fields.

Functions

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func AuthMethodEQ

func AuthMethodEQ(v AuthMethod) predicate.User

AuthMethodEQ applies the EQ predicate on the "auth_method" field.

func AuthMethodIn

func AuthMethodIn(vs ...AuthMethod) predicate.User

AuthMethodIn applies the In predicate on the "auth_method" field.

func AuthMethodNEQ

func AuthMethodNEQ(v AuthMethod) predicate.User

AuthMethodNEQ applies the NEQ predicate on the "auth_method" field.

func AuthMethodNotIn

func AuthMethodNotIn(vs ...AuthMethod) predicate.User

AuthMethodNotIn applies the NotIn predicate on the "auth_method" field.

func AuthMethodValidator

func AuthMethodValidator(am AuthMethod) error

AuthMethodValidator is a validator for the "auth_method" field enum values. It is called by the builders before save.

func CreateTime

func CreateTime(v time.Time) predicate.User

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.User

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.User

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.User

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.User

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.User

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.User

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.User

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.User

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func DisplayName

func DisplayName(v string) predicate.User

DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.

func DisplayNameContains

func DisplayNameContains(v string) predicate.User

DisplayNameContains applies the Contains predicate on the "display_name" field.

func DisplayNameContainsFold

func DisplayNameContainsFold(v string) predicate.User

DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.

func DisplayNameEQ

func DisplayNameEQ(v string) predicate.User

DisplayNameEQ applies the EQ predicate on the "display_name" field.

func DisplayNameEqualFold

func DisplayNameEqualFold(v string) predicate.User

DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.

func DisplayNameGT

func DisplayNameGT(v string) predicate.User

DisplayNameGT applies the GT predicate on the "display_name" field.

func DisplayNameGTE

func DisplayNameGTE(v string) predicate.User

DisplayNameGTE applies the GTE predicate on the "display_name" field.

func DisplayNameHasPrefix

func DisplayNameHasPrefix(v string) predicate.User

DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.

func DisplayNameHasSuffix

func DisplayNameHasSuffix(v string) predicate.User

DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.

func DisplayNameIn

func DisplayNameIn(vs ...string) predicate.User

DisplayNameIn applies the In predicate on the "display_name" field.

func DisplayNameIsNil

func DisplayNameIsNil() predicate.User

DisplayNameIsNil applies the IsNil predicate on the "display_name" field.

func DisplayNameLT

func DisplayNameLT(v string) predicate.User

DisplayNameLT applies the LT predicate on the "display_name" field.

func DisplayNameLTE

func DisplayNameLTE(v string) predicate.User

DisplayNameLTE applies the LTE predicate on the "display_name" field.

func DisplayNameNEQ

func DisplayNameNEQ(v string) predicate.User

DisplayNameNEQ applies the NEQ predicate on the "display_name" field.

func DisplayNameNotIn

func DisplayNameNotIn(vs ...string) predicate.User

DisplayNameNotIn applies the NotIn predicate on the "display_name" field.

func DisplayNameNotNil

func DisplayNameNotNil() predicate.User

DisplayNameNotNil applies the NotNil predicate on the "display_name" field.

func Email

func Email(v string) predicate.User

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.User

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.User

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.User

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.User

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.User

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.User

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.User

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.User

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.User

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.User

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.User

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.User

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.User

EmailNotIn applies the NotIn predicate on the "email" field.

func FailedLoginCount

func FailedLoginCount(v uint8) predicate.User

FailedLoginCount applies equality check predicate on the "failed_login_count" field. It's identical to FailedLoginCountEQ.

func FailedLoginCountEQ

func FailedLoginCountEQ(v uint8) predicate.User

FailedLoginCountEQ applies the EQ predicate on the "failed_login_count" field.

func FailedLoginCountGT

func FailedLoginCountGT(v uint8) predicate.User

FailedLoginCountGT applies the GT predicate on the "failed_login_count" field.

func FailedLoginCountGTE

func FailedLoginCountGTE(v uint8) predicate.User

FailedLoginCountGTE applies the GTE predicate on the "failed_login_count" field.

func FailedLoginCountIn

func FailedLoginCountIn(vs ...uint8) predicate.User

FailedLoginCountIn applies the In predicate on the "failed_login_count" field.

func FailedLoginCountLT

func FailedLoginCountLT(v uint8) predicate.User

FailedLoginCountLT applies the LT predicate on the "failed_login_count" field.

func FailedLoginCountLTE

func FailedLoginCountLTE(v uint8) predicate.User

FailedLoginCountLTE applies the LTE predicate on the "failed_login_count" field.

func FailedLoginCountNEQ

func FailedLoginCountNEQ(v uint8) predicate.User

FailedLoginCountNEQ applies the NEQ predicate on the "failed_login_count" field.

func FailedLoginCountNotIn

func FailedLoginCountNotIn(vs ...uint8) predicate.User

FailedLoginCountNotIn applies the NotIn predicate on the "failed_login_count" field.

func HasAPIKeys

func HasAPIKeys() predicate.User

HasAPIKeys applies the HasEdge predicate on the "api_keys" edge.

func HasAPIKeysWith

func HasAPIKeysWith(preds ...predicate.ApiKey) predicate.User

HasAPIKeysWith applies the HasEdge predicate on the "api_keys" edge with a given conditions (other predicates).

func HasOidcIdentities

func HasOidcIdentities() predicate.User

HasOidcIdentities applies the HasEdge predicate on the "oidc_identities" edge.

func HasOidcIdentitiesWith

func HasOidcIdentitiesWith(preds ...predicate.OIDCIdentity) predicate.User

HasOidcIdentitiesWith applies the HasEdge predicate on the "oidc_identities" edge with a given conditions (other predicates).

func HasRequests

func HasRequests() predicate.User

HasRequests applies the HasEdge predicate on the "requests" edge.

func HasRequestsWith

func HasRequestsWith(preds ...predicate.Request) predicate.User

HasRequestsWith applies the HasEdge predicate on the "requests" edge with a given conditions (other predicates).

func HasSessions

func HasSessions() predicate.User

HasSessions applies the HasEdge predicate on the "sessions" edge.

func HasSessionsWith

func HasSessionsWith(preds ...predicate.Session) predicate.User

HasSessionsWith applies the HasEdge predicate on the "sessions" edge with a given conditions (other predicates).

func ID

func ID(id uint32) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uint32) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uint32) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uint32) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint32) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uint32) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uint32) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uint32) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint32) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func LastFailedLoginAt

func LastFailedLoginAt(v time.Time) predicate.User

LastFailedLoginAt applies equality check predicate on the "last_failed_login_at" field. It's identical to LastFailedLoginAtEQ.

func LastFailedLoginAtEQ

func LastFailedLoginAtEQ(v time.Time) predicate.User

LastFailedLoginAtEQ applies the EQ predicate on the "last_failed_login_at" field.

func LastFailedLoginAtGT

func LastFailedLoginAtGT(v time.Time) predicate.User

LastFailedLoginAtGT applies the GT predicate on the "last_failed_login_at" field.

func LastFailedLoginAtGTE

func LastFailedLoginAtGTE(v time.Time) predicate.User

LastFailedLoginAtGTE applies the GTE predicate on the "last_failed_login_at" field.

func LastFailedLoginAtIn

func LastFailedLoginAtIn(vs ...time.Time) predicate.User

LastFailedLoginAtIn applies the In predicate on the "last_failed_login_at" field.

func LastFailedLoginAtIsNil

func LastFailedLoginAtIsNil() predicate.User

LastFailedLoginAtIsNil applies the IsNil predicate on the "last_failed_login_at" field.

func LastFailedLoginAtLT

func LastFailedLoginAtLT(v time.Time) predicate.User

LastFailedLoginAtLT applies the LT predicate on the "last_failed_login_at" field.

func LastFailedLoginAtLTE

func LastFailedLoginAtLTE(v time.Time) predicate.User

LastFailedLoginAtLTE applies the LTE predicate on the "last_failed_login_at" field.

func LastFailedLoginAtNEQ

func LastFailedLoginAtNEQ(v time.Time) predicate.User

LastFailedLoginAtNEQ applies the NEQ predicate on the "last_failed_login_at" field.

func LastFailedLoginAtNotIn

func LastFailedLoginAtNotIn(vs ...time.Time) predicate.User

LastFailedLoginAtNotIn applies the NotIn predicate on the "last_failed_login_at" field.

func LastFailedLoginAtNotNil

func LastFailedLoginAtNotNil() predicate.User

LastFailedLoginAtNotNil applies the NotNil predicate on the "last_failed_login_at" field.

func LockedUntil

func LockedUntil(v time.Time) predicate.User

LockedUntil applies equality check predicate on the "locked_until" field. It's identical to LockedUntilEQ.

func LockedUntilEQ

func LockedUntilEQ(v time.Time) predicate.User

LockedUntilEQ applies the EQ predicate on the "locked_until" field.

func LockedUntilGT

func LockedUntilGT(v time.Time) predicate.User

LockedUntilGT applies the GT predicate on the "locked_until" field.

func LockedUntilGTE

func LockedUntilGTE(v time.Time) predicate.User

LockedUntilGTE applies the GTE predicate on the "locked_until" field.

func LockedUntilIn

func LockedUntilIn(vs ...time.Time) predicate.User

LockedUntilIn applies the In predicate on the "locked_until" field.

func LockedUntilIsNil

func LockedUntilIsNil() predicate.User

LockedUntilIsNil applies the IsNil predicate on the "locked_until" field.

func LockedUntilLT

func LockedUntilLT(v time.Time) predicate.User

LockedUntilLT applies the LT predicate on the "locked_until" field.

func LockedUntilLTE

func LockedUntilLTE(v time.Time) predicate.User

LockedUntilLTE applies the LTE predicate on the "locked_until" field.

func LockedUntilNEQ

func LockedUntilNEQ(v time.Time) predicate.User

LockedUntilNEQ applies the NEQ predicate on the "locked_until" field.

func LockedUntilNotIn

func LockedUntilNotIn(vs ...time.Time) predicate.User

LockedUntilNotIn applies the NotIn predicate on the "locked_until" field.

func LockedUntilNotNil

func LockedUntilNotNil() predicate.User

LockedUntilNotNil applies the NotNil predicate on the "locked_until" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func PasswordHash

func PasswordHash(v string) predicate.User

PasswordHash applies equality check predicate on the "password_hash" field. It's identical to PasswordHashEQ.

func PasswordHashContains

func PasswordHashContains(v string) predicate.User

PasswordHashContains applies the Contains predicate on the "password_hash" field.

func PasswordHashContainsFold

func PasswordHashContainsFold(v string) predicate.User

PasswordHashContainsFold applies the ContainsFold predicate on the "password_hash" field.

func PasswordHashEQ

func PasswordHashEQ(v string) predicate.User

PasswordHashEQ applies the EQ predicate on the "password_hash" field.

func PasswordHashEqualFold

func PasswordHashEqualFold(v string) predicate.User

PasswordHashEqualFold applies the EqualFold predicate on the "password_hash" field.

func PasswordHashGT

func PasswordHashGT(v string) predicate.User

PasswordHashGT applies the GT predicate on the "password_hash" field.

func PasswordHashGTE

func PasswordHashGTE(v string) predicate.User

PasswordHashGTE applies the GTE predicate on the "password_hash" field.

func PasswordHashHasPrefix

func PasswordHashHasPrefix(v string) predicate.User

PasswordHashHasPrefix applies the HasPrefix predicate on the "password_hash" field.

func PasswordHashHasSuffix

func PasswordHashHasSuffix(v string) predicate.User

PasswordHashHasSuffix applies the HasSuffix predicate on the "password_hash" field.

func PasswordHashIn

func PasswordHashIn(vs ...string) predicate.User

PasswordHashIn applies the In predicate on the "password_hash" field.

func PasswordHashIsNil

func PasswordHashIsNil() predicate.User

PasswordHashIsNil applies the IsNil predicate on the "password_hash" field.

func PasswordHashLT

func PasswordHashLT(v string) predicate.User

PasswordHashLT applies the LT predicate on the "password_hash" field.

func PasswordHashLTE

func PasswordHashLTE(v string) predicate.User

PasswordHashLTE applies the LTE predicate on the "password_hash" field.

func PasswordHashNEQ

func PasswordHashNEQ(v string) predicate.User

PasswordHashNEQ applies the NEQ predicate on the "password_hash" field.

func PasswordHashNotIn

func PasswordHashNotIn(vs ...string) predicate.User

PasswordHashNotIn applies the NotIn predicate on the "password_hash" field.

func PasswordHashNotNil

func PasswordHashNotNil() predicate.User

PasswordHashNotNil applies the NotNil predicate on the "password_hash" field.

func RoleEQ

func RoleEQ(v Role) predicate.User

RoleEQ applies the EQ predicate on the "role" field.

func RoleIn

func RoleIn(vs ...Role) predicate.User

RoleIn applies the In predicate on the "role" field.

func RoleNEQ

func RoleNEQ(v Role) predicate.User

RoleNEQ applies the NEQ predicate on the "role" field.

func RoleNotIn

func RoleNotIn(vs ...Role) predicate.User

RoleNotIn applies the NotIn predicate on the "role" field.

func RoleValidator

func RoleValidator(r Role) error

RoleValidator is a validator for the "role" field enum values. It is called by the builders before save.

func UpdateTime

func UpdateTime(v time.Time) predicate.User

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.User

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.User

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.User

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.User

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.User

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.User

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.User

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.User

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type AuthMethod

type AuthMethod string

AuthMethod defines the type for the "auth_method" enum field.

const (
	AuthMethodLocal AuthMethod = "local"
	AuthMethodOidc  AuthMethod = "oidc"
	AuthMethodBoth  AuthMethod = "both"
)

AuthMethod values.

func (AuthMethod) String

func (am AuthMethod) String() string

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByAPIKeys

func ByAPIKeys(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByAPIKeys orders the results by api_keys terms.

func ByAPIKeysCount

func ByAPIKeysCount(opts ...sql.OrderTermOption) OrderOption

ByAPIKeysCount orders the results by api_keys count.

func ByAuthMethod

func ByAuthMethod(opts ...sql.OrderTermOption) OrderOption

ByAuthMethod orders the results by the auth_method field.

func ByCreateTime

func ByCreateTime(opts ...sql.OrderTermOption) OrderOption

ByCreateTime orders the results by the create_time field.

func ByDisplayName

func ByDisplayName(opts ...sql.OrderTermOption) OrderOption

ByDisplayName orders the results by the display_name field.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByFailedLoginCount

func ByFailedLoginCount(opts ...sql.OrderTermOption) OrderOption

ByFailedLoginCount orders the results by the failed_login_count field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastFailedLoginAt

func ByLastFailedLoginAt(opts ...sql.OrderTermOption) OrderOption

ByLastFailedLoginAt orders the results by the last_failed_login_at field.

func ByLockedUntil

func ByLockedUntil(opts ...sql.OrderTermOption) OrderOption

ByLockedUntil orders the results by the locked_until field.

func ByOidcIdentities

func ByOidcIdentities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByOidcIdentities orders the results by oidc_identities terms.

func ByOidcIdentitiesCount

func ByOidcIdentitiesCount(opts ...sql.OrderTermOption) OrderOption

ByOidcIdentitiesCount orders the results by oidc_identities count.

func ByPasswordHash

func ByPasswordHash(opts ...sql.OrderTermOption) OrderOption

ByPasswordHash orders the results by the password_hash field.

func ByRequests

func ByRequests(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByRequests orders the results by requests terms.

func ByRequestsCount

func ByRequestsCount(opts ...sql.OrderTermOption) OrderOption

ByRequestsCount orders the results by requests count.

func ByRole

func ByRole(opts ...sql.OrderTermOption) OrderOption

ByRole orders the results by the role field.

func BySessions

func BySessions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

BySessions orders the results by sessions terms.

func BySessionsCount

func BySessionsCount(opts ...sql.OrderTermOption) OrderOption

BySessionsCount orders the results by sessions count.

func ByUpdateTime

func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption

ByUpdateTime orders the results by the update_time field.

type Role

type Role string

Role defines the type for the "role" enum field.

const (
	RoleAdmin       Role = "admin"
	RoleMember      Role = "member"
	RoleRequestOnly Role = "request_only"
)

Role values.

func (Role) String

func (r Role) String() string

Jump to