Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Movie) predicate.Movie
- func CreateTime(v time.Time) predicate.Movie
- func CreateTimeEQ(v time.Time) predicate.Movie
- func CreateTimeGT(v time.Time) predicate.Movie
- func CreateTimeGTE(v time.Time) predicate.Movie
- func CreateTimeIn(vs ...time.Time) predicate.Movie
- func CreateTimeLT(v time.Time) predicate.Movie
- func CreateTimeLTE(v time.Time) predicate.Movie
- func CreateTimeNEQ(v time.Time) predicate.Movie
- func CreateTimeNotIn(vs ...time.Time) predicate.Movie
- func DigitalReleaseDate(v time.Time) predicate.Movie
- func DigitalReleaseDateEQ(v time.Time) predicate.Movie
- func DigitalReleaseDateGT(v time.Time) predicate.Movie
- func DigitalReleaseDateGTE(v time.Time) predicate.Movie
- func DigitalReleaseDateIn(vs ...time.Time) predicate.Movie
- func DigitalReleaseDateIsNil() predicate.Movie
- func DigitalReleaseDateLT(v time.Time) predicate.Movie
- func DigitalReleaseDateLTE(v time.Time) predicate.Movie
- func DigitalReleaseDateNEQ(v time.Time) predicate.Movie
- func DigitalReleaseDateNotIn(vs ...time.Time) predicate.Movie
- func DigitalReleaseDateNotNil() predicate.Movie
- func FailureReason(v string) predicate.Movie
- func FailureReasonContains(v string) predicate.Movie
- func FailureReasonContainsFold(v string) predicate.Movie
- func FailureReasonEQ(v string) predicate.Movie
- func FailureReasonEqualFold(v string) predicate.Movie
- func FailureReasonGT(v string) predicate.Movie
- func FailureReasonGTE(v string) predicate.Movie
- func FailureReasonHasPrefix(v string) predicate.Movie
- func FailureReasonHasSuffix(v string) predicate.Movie
- func FailureReasonIn(vs ...string) predicate.Movie
- func FailureReasonIsNil() predicate.Movie
- func FailureReasonLT(v string) predicate.Movie
- func FailureReasonLTE(v string) predicate.Movie
- func FailureReasonNEQ(v string) predicate.Movie
- func FailureReasonNotIn(vs ...string) predicate.Movie
- func FailureReasonNotNil() predicate.Movie
- func GrabFailures(v uint8) predicate.Movie
- func GrabFailuresEQ(v uint8) predicate.Movie
- func GrabFailuresGT(v uint8) predicate.Movie
- func GrabFailuresGTE(v uint8) predicate.Movie
- func GrabFailuresIn(vs ...uint8) predicate.Movie
- func GrabFailuresLT(v uint8) predicate.Movie
- func GrabFailuresLTE(v uint8) predicate.Movie
- func GrabFailuresNEQ(v uint8) predicate.Movie
- func GrabFailuresNotIn(vs ...uint8) predicate.Movie
- func HasDownloadRecords() predicate.Movie
- func HasDownloadRecordsWith(preds ...predicate.DownloadRecord) predicate.Movie
- func HasEvents() predicate.Movie
- func HasEventsWith(preds ...predicate.MovieEvent) predicate.Movie
- func HasMediaFiles() predicate.Movie
- func HasMediaFilesWith(preds ...predicate.MediaFile) predicate.Movie
- func ID(id uint32) predicate.Movie
- func IDEQ(id uint32) predicate.Movie
- func IDGT(id uint32) predicate.Movie
- func IDGTE(id uint32) predicate.Movie
- func IDIn(ids ...uint32) predicate.Movie
- func IDLT(id uint32) predicate.Movie
- func IDLTE(id uint32) predicate.Movie
- func IDNEQ(id uint32) predicate.Movie
- func IDNotIn(ids ...uint32) predicate.Movie
- func LastSearchAt(v time.Time) predicate.Movie
- func LastSearchAtEQ(v time.Time) predicate.Movie
- func LastSearchAtGT(v time.Time) predicate.Movie
- func LastSearchAtGTE(v time.Time) predicate.Movie
- func LastSearchAtIn(vs ...time.Time) predicate.Movie
- func LastSearchAtIsNil() predicate.Movie
- func LastSearchAtLT(v time.Time) predicate.Movie
- func LastSearchAtLTE(v time.Time) predicate.Movie
- func LastSearchAtNEQ(v time.Time) predicate.Movie
- func LastSearchAtNotIn(vs ...time.Time) predicate.Movie
- func LastSearchAtNotNil() predicate.Movie
- func Monitored(v bool) predicate.Movie
- func MonitoredEQ(v bool) predicate.Movie
- func MonitoredNEQ(v bool) predicate.Movie
- func Not(p predicate.Movie) predicate.Movie
- func Or(predicates ...predicate.Movie) predicate.Movie
- func OriginalTitle(v string) predicate.Movie
- func OriginalTitleContains(v string) predicate.Movie
- func OriginalTitleContainsFold(v string) predicate.Movie
- func OriginalTitleEQ(v string) predicate.Movie
- func OriginalTitleEqualFold(v string) predicate.Movie
- func OriginalTitleGT(v string) predicate.Movie
- func OriginalTitleGTE(v string) predicate.Movie
- func OriginalTitleHasPrefix(v string) predicate.Movie
- func OriginalTitleHasSuffix(v string) predicate.Movie
- func OriginalTitleIn(vs ...string) predicate.Movie
- func OriginalTitleLT(v string) predicate.Movie
- func OriginalTitleLTE(v string) predicate.Movie
- func OriginalTitleNEQ(v string) predicate.Movie
- func OriginalTitleNotIn(vs ...string) predicate.Movie
- func Overview(v string) predicate.Movie
- func OverviewContains(v string) predicate.Movie
- func OverviewContainsFold(v string) predicate.Movie
- func OverviewEQ(v string) predicate.Movie
- func OverviewEqualFold(v string) predicate.Movie
- func OverviewGT(v string) predicate.Movie
- func OverviewGTE(v string) predicate.Movie
- func OverviewHasPrefix(v string) predicate.Movie
- func OverviewHasSuffix(v string) predicate.Movie
- func OverviewIn(vs ...string) predicate.Movie
- func OverviewIsNil() predicate.Movie
- func OverviewLT(v string) predicate.Movie
- func OverviewLTE(v string) predicate.Movie
- func OverviewNEQ(v string) predicate.Movie
- func OverviewNotIn(vs ...string) predicate.Movie
- func OverviewNotNil() predicate.Movie
- func QualityProfile(v string) predicate.Movie
- func QualityProfileContains(v string) predicate.Movie
- func QualityProfileContainsFold(v string) predicate.Movie
- func QualityProfileEQ(v string) predicate.Movie
- func QualityProfileEqualFold(v string) predicate.Movie
- func QualityProfileGT(v string) predicate.Movie
- func QualityProfileGTE(v string) predicate.Movie
- func QualityProfileHasPrefix(v string) predicate.Movie
- func QualityProfileHasSuffix(v string) predicate.Movie
- func QualityProfileIn(vs ...string) predicate.Movie
- func QualityProfileIsNil() predicate.Movie
- func QualityProfileLT(v string) predicate.Movie
- func QualityProfileLTE(v string) predicate.Movie
- func QualityProfileNEQ(v string) predicate.Movie
- func QualityProfileNotIn(vs ...string) predicate.Movie
- func QualityProfileNotNil() predicate.Movie
- func Runtime(v uint16) predicate.Movie
- func RuntimeEQ(v uint16) predicate.Movie
- func RuntimeGT(v uint16) predicate.Movie
- func RuntimeGTE(v uint16) predicate.Movie
- func RuntimeIn(vs ...uint16) predicate.Movie
- func RuntimeIsNil() predicate.Movie
- func RuntimeLT(v uint16) predicate.Movie
- func RuntimeLTE(v uint16) predicate.Movie
- func RuntimeNEQ(v uint16) predicate.Movie
- func RuntimeNotIn(vs ...uint16) predicate.Movie
- func RuntimeNotNil() predicate.Movie
- func StatusEQ(v Status) predicate.Movie
- func StatusIn(vs ...Status) predicate.Movie
- func StatusNEQ(v Status) predicate.Movie
- func StatusNotIn(vs ...Status) predicate.Movie
- func StatusValidator(s Status) error
- func Title(v string) predicate.Movie
- func TitleContains(v string) predicate.Movie
- func TitleContainsFold(v string) predicate.Movie
- func TitleEQ(v string) predicate.Movie
- func TitleEqualFold(v string) predicate.Movie
- func TitleGT(v string) predicate.Movie
- func TitleGTE(v string) predicate.Movie
- func TitleHasPrefix(v string) predicate.Movie
- func TitleHasSuffix(v string) predicate.Movie
- func TitleIn(vs ...string) predicate.Movie
- func TitleLT(v string) predicate.Movie
- func TitleLTE(v string) predicate.Movie
- func TitleNEQ(v string) predicate.Movie
- func TitleNotIn(vs ...string) predicate.Movie
- func TmdbID(v uint32) predicate.Movie
- func TmdbIDEQ(v uint32) predicate.Movie
- func TmdbIDGT(v uint32) predicate.Movie
- func TmdbIDGTE(v uint32) predicate.Movie
- func TmdbIDIn(vs ...uint32) predicate.Movie
- func TmdbIDLT(v uint32) predicate.Movie
- func TmdbIDLTE(v uint32) predicate.Movie
- func TmdbIDNEQ(v uint32) predicate.Movie
- func TmdbIDNotIn(vs ...uint32) predicate.Movie
- func UpdateTime(v time.Time) predicate.Movie
- func UpdateTimeEQ(v time.Time) predicate.Movie
- func UpdateTimeGT(v time.Time) predicate.Movie
- func UpdateTimeGTE(v time.Time) predicate.Movie
- func UpdateTimeIn(vs ...time.Time) predicate.Movie
- func UpdateTimeLT(v time.Time) predicate.Movie
- func UpdateTimeLTE(v time.Time) predicate.Movie
- func UpdateTimeNEQ(v time.Time) predicate.Movie
- func UpdateTimeNotIn(vs ...time.Time) predicate.Movie
- func ValidColumn(column string) bool
- func Year(v uint16) predicate.Movie
- func YearEQ(v uint16) predicate.Movie
- func YearGT(v uint16) predicate.Movie
- func YearGTE(v uint16) predicate.Movie
- func YearIn(vs ...uint16) predicate.Movie
- func YearLT(v uint16) predicate.Movie
- func YearLTE(v uint16) predicate.Movie
- func YearNEQ(v uint16) predicate.Movie
- func YearNotIn(vs ...uint16) predicate.Movie
- type OrderOption
- func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
- func ByDigitalReleaseDate(opts ...sql.OrderTermOption) OrderOption
- func ByDownloadRecords(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByDownloadRecordsCount(opts ...sql.OrderTermOption) OrderOption
- func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
- func ByFailureReason(opts ...sql.OrderTermOption) OrderOption
- func ByGrabFailures(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastSearchAt(opts ...sql.OrderTermOption) OrderOption
- func ByMediaFiles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByMediaFilesCount(opts ...sql.OrderTermOption) OrderOption
- func ByMonitored(opts ...sql.OrderTermOption) OrderOption
- func ByOriginalTitle(opts ...sql.OrderTermOption) OrderOption
- func ByOverview(opts ...sql.OrderTermOption) OrderOption
- func ByQualityProfile(opts ...sql.OrderTermOption) OrderOption
- func ByRuntime(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByTitle(opts ...sql.OrderTermOption) OrderOption
- func ByTmdbID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
- func ByYear(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the movie type in the database. Label = "movie" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldTitle holds the string denoting the title field in the database. FieldTitle = "title" // FieldOriginalTitle holds the string denoting the original_title field in the database. FieldOriginalTitle = "original_title" // FieldYear holds the string denoting the year field in the database. FieldYear = "year" // FieldOverview holds the string denoting the overview field in the database. FieldOverview = "overview" // FieldRuntime holds the string denoting the runtime field in the database. FieldRuntime = "runtime" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldMonitored holds the string denoting the monitored field in the database. FieldMonitored = "monitored" // FieldTmdbID holds the string denoting the tmdb_id field in the database. FieldTmdbID = "tmdb_id" // FieldLastSearchAt holds the string denoting the last_search_at field in the database. FieldLastSearchAt = "last_search_at" // FieldDigitalReleaseDate holds the string denoting the digital_release_date field in the database. FieldDigitalReleaseDate = "digital_release_date" // FieldGrabFailures holds the string denoting the grab_failures field in the database. FieldGrabFailures = "grab_failures" // FieldFailureReason holds the string denoting the failure_reason field in the database. FieldFailureReason = "failure_reason" // FieldQualityProfile holds the string denoting the quality_profile field in the database. FieldQualityProfile = "quality_profile" // EdgeDownloadRecords holds the string denoting the download_records edge name in mutations. EdgeDownloadRecords = "download_records" // EdgeMediaFiles holds the string denoting the media_files edge name in mutations. EdgeMediaFiles = "media_files" // EdgeEvents holds the string denoting the events edge name in mutations. EdgeEvents = "events" // Table holds the table name of the movie in the database. Table = "movies" // DownloadRecordsTable is the table that holds the download_records relation/edge. DownloadRecordsTable = "download_records" // DownloadRecordsInverseTable is the table name for the DownloadRecord entity. // It exists in this package in order to avoid circular dependency with the "downloadrecord" package. DownloadRecordsInverseTable = "download_records" // DownloadRecordsColumn is the table column denoting the download_records relation/edge. DownloadRecordsColumn = "movie_download_records" // MediaFilesTable is the table that holds the media_files relation/edge. MediaFilesTable = "media_files" // MediaFilesInverseTable is the table name for the MediaFile entity. // It exists in this package in order to avoid circular dependency with the "mediafile" package. MediaFilesInverseTable = "media_files" // MediaFilesColumn is the table column denoting the media_files relation/edge. MediaFilesColumn = "movie_media_files" // EventsTable is the table that holds the events relation/edge. EventsTable = "movie_events" // EventsInverseTable is the table name for the MovieEvent entity. // It exists in this package in order to avoid circular dependency with the "movieevent" package. EventsInverseTable = "movie_events" // EventsColumn is the table column denoting the events relation/edge. EventsColumn = "movie_events" )
const DefaultStatus = StatusWanted
StatusWanted is the default value of the Status enum.
Variables ¶
var ( // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // TitleValidator is a validator for the "title" field. It is called by the builders before save. TitleValidator func(string) error // OriginalTitleValidator is a validator for the "original_title" field. It is called by the builders before save. OriginalTitleValidator func(string) error // DefaultRuntime holds the default value on creation for the "runtime" field. DefaultRuntime uint16 // DefaultMonitored holds the default value on creation for the "monitored" field. DefaultMonitored bool // DefaultGrabFailures holds the default value on creation for the "grab_failures" field. DefaultGrabFailures uint8 )
var Columns = []string{ FieldID, FieldCreateTime, FieldUpdateTime, FieldTitle, FieldOriginalTitle, FieldYear, FieldOverview, FieldRuntime, FieldStatus, FieldMonitored, FieldTmdbID, FieldLastSearchAt, FieldDigitalReleaseDate, FieldGrabFailures, FieldFailureReason, FieldQualityProfile, }
Columns holds all SQL columns for movie fields.
Functions ¶
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func DigitalReleaseDate ¶
DigitalReleaseDate applies equality check predicate on the "digital_release_date" field. It's identical to DigitalReleaseDateEQ.
func DigitalReleaseDateEQ ¶
DigitalReleaseDateEQ applies the EQ predicate on the "digital_release_date" field.
func DigitalReleaseDateGT ¶
DigitalReleaseDateGT applies the GT predicate on the "digital_release_date" field.
func DigitalReleaseDateGTE ¶
DigitalReleaseDateGTE applies the GTE predicate on the "digital_release_date" field.
func DigitalReleaseDateIn ¶
DigitalReleaseDateIn applies the In predicate on the "digital_release_date" field.
func DigitalReleaseDateIsNil ¶
DigitalReleaseDateIsNil applies the IsNil predicate on the "digital_release_date" field.
func DigitalReleaseDateLT ¶
DigitalReleaseDateLT applies the LT predicate on the "digital_release_date" field.
func DigitalReleaseDateLTE ¶
DigitalReleaseDateLTE applies the LTE predicate on the "digital_release_date" field.
func DigitalReleaseDateNEQ ¶
DigitalReleaseDateNEQ applies the NEQ predicate on the "digital_release_date" field.
func DigitalReleaseDateNotIn ¶
DigitalReleaseDateNotIn applies the NotIn predicate on the "digital_release_date" field.
func DigitalReleaseDateNotNil ¶
DigitalReleaseDateNotNil applies the NotNil predicate on the "digital_release_date" field.
func FailureReason ¶
FailureReason applies equality check predicate on the "failure_reason" field. It's identical to FailureReasonEQ.
func FailureReasonContains ¶
FailureReasonContains applies the Contains predicate on the "failure_reason" field.
func FailureReasonContainsFold ¶
FailureReasonContainsFold applies the ContainsFold predicate on the "failure_reason" field.
func FailureReasonEQ ¶
FailureReasonEQ applies the EQ predicate on the "failure_reason" field.
func FailureReasonEqualFold ¶
FailureReasonEqualFold applies the EqualFold predicate on the "failure_reason" field.
func FailureReasonGT ¶
FailureReasonGT applies the GT predicate on the "failure_reason" field.
func FailureReasonGTE ¶
FailureReasonGTE applies the GTE predicate on the "failure_reason" field.
func FailureReasonHasPrefix ¶
FailureReasonHasPrefix applies the HasPrefix predicate on the "failure_reason" field.
func FailureReasonHasSuffix ¶
FailureReasonHasSuffix applies the HasSuffix predicate on the "failure_reason" field.
func FailureReasonIn ¶
FailureReasonIn applies the In predicate on the "failure_reason" field.
func FailureReasonIsNil ¶
FailureReasonIsNil applies the IsNil predicate on the "failure_reason" field.
func FailureReasonLT ¶
FailureReasonLT applies the LT predicate on the "failure_reason" field.
func FailureReasonLTE ¶
FailureReasonLTE applies the LTE predicate on the "failure_reason" field.
func FailureReasonNEQ ¶
FailureReasonNEQ applies the NEQ predicate on the "failure_reason" field.
func FailureReasonNotIn ¶
FailureReasonNotIn applies the NotIn predicate on the "failure_reason" field.
func FailureReasonNotNil ¶
FailureReasonNotNil applies the NotNil predicate on the "failure_reason" field.
func GrabFailures ¶
GrabFailures applies equality check predicate on the "grab_failures" field. It's identical to GrabFailuresEQ.
func GrabFailuresEQ ¶
GrabFailuresEQ applies the EQ predicate on the "grab_failures" field.
func GrabFailuresGT ¶
GrabFailuresGT applies the GT predicate on the "grab_failures" field.
func GrabFailuresGTE ¶
GrabFailuresGTE applies the GTE predicate on the "grab_failures" field.
func GrabFailuresIn ¶
GrabFailuresIn applies the In predicate on the "grab_failures" field.
func GrabFailuresLT ¶
GrabFailuresLT applies the LT predicate on the "grab_failures" field.
func GrabFailuresLTE ¶
GrabFailuresLTE applies the LTE predicate on the "grab_failures" field.
func GrabFailuresNEQ ¶
GrabFailuresNEQ applies the NEQ predicate on the "grab_failures" field.
func GrabFailuresNotIn ¶
GrabFailuresNotIn applies the NotIn predicate on the "grab_failures" field.
func HasDownloadRecords ¶
HasDownloadRecords applies the HasEdge predicate on the "download_records" edge.
func HasDownloadRecordsWith ¶
func HasDownloadRecordsWith(preds ...predicate.DownloadRecord) predicate.Movie
HasDownloadRecordsWith applies the HasEdge predicate on the "download_records" edge with a given conditions (other predicates).
func HasEventsWith ¶
func HasEventsWith(preds ...predicate.MovieEvent) predicate.Movie
HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).
func HasMediaFiles ¶
HasMediaFiles applies the HasEdge predicate on the "media_files" edge.
func HasMediaFilesWith ¶
HasMediaFilesWith applies the HasEdge predicate on the "media_files" edge with a given conditions (other predicates).
func LastSearchAt ¶
LastSearchAt applies equality check predicate on the "last_search_at" field. It's identical to LastSearchAtEQ.
func LastSearchAtEQ ¶
LastSearchAtEQ applies the EQ predicate on the "last_search_at" field.
func LastSearchAtGT ¶
LastSearchAtGT applies the GT predicate on the "last_search_at" field.
func LastSearchAtGTE ¶
LastSearchAtGTE applies the GTE predicate on the "last_search_at" field.
func LastSearchAtIn ¶
LastSearchAtIn applies the In predicate on the "last_search_at" field.
func LastSearchAtIsNil ¶
LastSearchAtIsNil applies the IsNil predicate on the "last_search_at" field.
func LastSearchAtLT ¶
LastSearchAtLT applies the LT predicate on the "last_search_at" field.
func LastSearchAtLTE ¶
LastSearchAtLTE applies the LTE predicate on the "last_search_at" field.
func LastSearchAtNEQ ¶
LastSearchAtNEQ applies the NEQ predicate on the "last_search_at" field.
func LastSearchAtNotIn ¶
LastSearchAtNotIn applies the NotIn predicate on the "last_search_at" field.
func LastSearchAtNotNil ¶
LastSearchAtNotNil applies the NotNil predicate on the "last_search_at" field.
func Monitored ¶
Monitored applies equality check predicate on the "monitored" field. It's identical to MonitoredEQ.
func MonitoredEQ ¶
MonitoredEQ applies the EQ predicate on the "monitored" field.
func MonitoredNEQ ¶
MonitoredNEQ applies the NEQ predicate on the "monitored" field.
func OriginalTitle ¶
OriginalTitle applies equality check predicate on the "original_title" field. It's identical to OriginalTitleEQ.
func OriginalTitleContains ¶
OriginalTitleContains applies the Contains predicate on the "original_title" field.
func OriginalTitleContainsFold ¶
OriginalTitleContainsFold applies the ContainsFold predicate on the "original_title" field.
func OriginalTitleEQ ¶
OriginalTitleEQ applies the EQ predicate on the "original_title" field.
func OriginalTitleEqualFold ¶
OriginalTitleEqualFold applies the EqualFold predicate on the "original_title" field.
func OriginalTitleGT ¶
OriginalTitleGT applies the GT predicate on the "original_title" field.
func OriginalTitleGTE ¶
OriginalTitleGTE applies the GTE predicate on the "original_title" field.
func OriginalTitleHasPrefix ¶
OriginalTitleHasPrefix applies the HasPrefix predicate on the "original_title" field.
func OriginalTitleHasSuffix ¶
OriginalTitleHasSuffix applies the HasSuffix predicate on the "original_title" field.
func OriginalTitleIn ¶
OriginalTitleIn applies the In predicate on the "original_title" field.
func OriginalTitleLT ¶
OriginalTitleLT applies the LT predicate on the "original_title" field.
func OriginalTitleLTE ¶
OriginalTitleLTE applies the LTE predicate on the "original_title" field.
func OriginalTitleNEQ ¶
OriginalTitleNEQ applies the NEQ predicate on the "original_title" field.
func OriginalTitleNotIn ¶
OriginalTitleNotIn applies the NotIn predicate on the "original_title" field.
func Overview ¶
Overview applies equality check predicate on the "overview" field. It's identical to OverviewEQ.
func OverviewContains ¶
OverviewContains applies the Contains predicate on the "overview" field.
func OverviewContainsFold ¶
OverviewContainsFold applies the ContainsFold predicate on the "overview" field.
func OverviewEQ ¶
OverviewEQ applies the EQ predicate on the "overview" field.
func OverviewEqualFold ¶
OverviewEqualFold applies the EqualFold predicate on the "overview" field.
func OverviewGT ¶
OverviewGT applies the GT predicate on the "overview" field.
func OverviewGTE ¶
OverviewGTE applies the GTE predicate on the "overview" field.
func OverviewHasPrefix ¶
OverviewHasPrefix applies the HasPrefix predicate on the "overview" field.
func OverviewHasSuffix ¶
OverviewHasSuffix applies the HasSuffix predicate on the "overview" field.
func OverviewIn ¶
OverviewIn applies the In predicate on the "overview" field.
func OverviewIsNil ¶
OverviewIsNil applies the IsNil predicate on the "overview" field.
func OverviewLT ¶
OverviewLT applies the LT predicate on the "overview" field.
func OverviewLTE ¶
OverviewLTE applies the LTE predicate on the "overview" field.
func OverviewNEQ ¶
OverviewNEQ applies the NEQ predicate on the "overview" field.
func OverviewNotIn ¶
OverviewNotIn applies the NotIn predicate on the "overview" field.
func OverviewNotNil ¶
OverviewNotNil applies the NotNil predicate on the "overview" field.
func QualityProfile ¶
QualityProfile applies equality check predicate on the "quality_profile" field. It's identical to QualityProfileEQ.
func QualityProfileContains ¶
QualityProfileContains applies the Contains predicate on the "quality_profile" field.
func QualityProfileContainsFold ¶
QualityProfileContainsFold applies the ContainsFold predicate on the "quality_profile" field.
func QualityProfileEQ ¶
QualityProfileEQ applies the EQ predicate on the "quality_profile" field.
func QualityProfileEqualFold ¶
QualityProfileEqualFold applies the EqualFold predicate on the "quality_profile" field.
func QualityProfileGT ¶
QualityProfileGT applies the GT predicate on the "quality_profile" field.
func QualityProfileGTE ¶
QualityProfileGTE applies the GTE predicate on the "quality_profile" field.
func QualityProfileHasPrefix ¶
QualityProfileHasPrefix applies the HasPrefix predicate on the "quality_profile" field.
func QualityProfileHasSuffix ¶
QualityProfileHasSuffix applies the HasSuffix predicate on the "quality_profile" field.
func QualityProfileIn ¶
QualityProfileIn applies the In predicate on the "quality_profile" field.
func QualityProfileIsNil ¶
QualityProfileIsNil applies the IsNil predicate on the "quality_profile" field.
func QualityProfileLT ¶
QualityProfileLT applies the LT predicate on the "quality_profile" field.
func QualityProfileLTE ¶
QualityProfileLTE applies the LTE predicate on the "quality_profile" field.
func QualityProfileNEQ ¶
QualityProfileNEQ applies the NEQ predicate on the "quality_profile" field.
func QualityProfileNotIn ¶
QualityProfileNotIn applies the NotIn predicate on the "quality_profile" field.
func QualityProfileNotNil ¶
QualityProfileNotNil applies the NotNil predicate on the "quality_profile" field.
func Runtime ¶
Runtime applies equality check predicate on the "runtime" field. It's identical to RuntimeEQ.
func RuntimeGTE ¶
RuntimeGTE applies the GTE predicate on the "runtime" field.
func RuntimeIsNil ¶
RuntimeIsNil applies the IsNil predicate on the "runtime" field.
func RuntimeLTE ¶
RuntimeLTE applies the LTE predicate on the "runtime" field.
func RuntimeNEQ ¶
RuntimeNEQ applies the NEQ predicate on the "runtime" field.
func RuntimeNotIn ¶
RuntimeNotIn applies the NotIn predicate on the "runtime" field.
func RuntimeNotNil ¶
RuntimeNotNil applies the NotNil predicate on the "runtime" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func Title ¶
Title applies equality check predicate on the "title" field. It's identical to TitleEQ.
func TitleContains ¶
TitleContains applies the Contains predicate on the "title" field.
func TitleContainsFold ¶
TitleContainsFold applies the ContainsFold predicate on the "title" field.
func TitleEqualFold ¶
TitleEqualFold applies the EqualFold predicate on the "title" field.
func TitleHasPrefix ¶
TitleHasPrefix applies the HasPrefix predicate on the "title" field.
func TitleHasSuffix ¶
TitleHasSuffix applies the HasSuffix predicate on the "title" field.
func TitleNotIn ¶
TitleNotIn applies the NotIn predicate on the "title" field.
func TmdbID ¶
TmdbID applies equality check predicate on the "tmdb_id" field. It's identical to TmdbIDEQ.
func TmdbIDNotIn ¶
TmdbIDNotIn applies the NotIn predicate on the "tmdb_id" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Movie queries.
func ByCreateTime ¶
func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
ByCreateTime orders the results by the create_time field.
func ByDigitalReleaseDate ¶
func ByDigitalReleaseDate(opts ...sql.OrderTermOption) OrderOption
ByDigitalReleaseDate orders the results by the digital_release_date field.
func ByDownloadRecords ¶
func ByDownloadRecords(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByDownloadRecords orders the results by download_records terms.
func ByDownloadRecordsCount ¶
func ByDownloadRecordsCount(opts ...sql.OrderTermOption) OrderOption
ByDownloadRecordsCount orders the results by download_records count.
func ByEvents ¶
func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvents orders the results by events terms.
func ByEventsCount ¶
func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
ByEventsCount orders the results by events count.
func ByFailureReason ¶
func ByFailureReason(opts ...sql.OrderTermOption) OrderOption
ByFailureReason orders the results by the failure_reason field.
func ByGrabFailures ¶
func ByGrabFailures(opts ...sql.OrderTermOption) OrderOption
ByGrabFailures orders the results by the grab_failures field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastSearchAt ¶
func ByLastSearchAt(opts ...sql.OrderTermOption) OrderOption
ByLastSearchAt orders the results by the last_search_at field.
func ByMediaFiles ¶
func ByMediaFiles(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByMediaFiles orders the results by media_files terms.
func ByMediaFilesCount ¶
func ByMediaFilesCount(opts ...sql.OrderTermOption) OrderOption
ByMediaFilesCount orders the results by media_files count.
func ByMonitored ¶
func ByMonitored(opts ...sql.OrderTermOption) OrderOption
ByMonitored orders the results by the monitored field.
func ByOriginalTitle ¶
func ByOriginalTitle(opts ...sql.OrderTermOption) OrderOption
ByOriginalTitle orders the results by the original_title field.
func ByOverview ¶
func ByOverview(opts ...sql.OrderTermOption) OrderOption
ByOverview orders the results by the overview field.
func ByQualityProfile ¶
func ByQualityProfile(opts ...sql.OrderTermOption) OrderOption
ByQualityProfile orders the results by the quality_profile field.
func ByRuntime ¶
func ByRuntime(opts ...sql.OrderTermOption) OrderOption
ByRuntime orders the results by the runtime field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByTitle ¶
func ByTitle(opts ...sql.OrderTermOption) OrderOption
ByTitle orders the results by the title field.
func ByTmdbID ¶
func ByTmdbID(opts ...sql.OrderTermOption) OrderOption
ByTmdbID orders the results by the tmdb_id field.
func ByUpdateTime ¶
func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
ByUpdateTime orders the results by the update_time field.
func ByYear ¶
func ByYear(opts ...sql.OrderTermOption) OrderOption
ByYear orders the results by the year field.